package com.download.library;

import android.app.Activity;
import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.SystemClock;
import android.text.TextUtils;
import androidx.core.app.NotificationCompat;
import androidx.recyclerview.widget.ItemTouchHelper;
import com.queue.library.BuildConfig;
import com.queue.library.DispatchThread;
import com.queue.library.GlobalQueue;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Locale;

public class DownloadNotifier {
    private static final int FLAG = 4;
    private static volatile DispatchThread NOTIFICATION_UPDATE_QUEUE = null;
    private static final String TAG = "Download-DownloadNotifier";
    private static long sLastUpdateNoticationTime = SystemClock.elapsedRealtime();
    private NotificationCompat.Action mAction;
    private volatile boolean mAddedCancelAction = false;
    private NotificationCompat.Builder mBuilder;
    private String mContent = BuildConfig.FLAVOR;
    private Context mContext;
    private DownloadTask mDownloadTask;
    private Notification mNotification;
    private int mNotificationId;
    private NotificationManager mNotificationManager;
    int requestCode = ((int) SystemClock.uptimeMillis());

    private static DispatchThread getNotificationUpdateQueue() {
        if (NOTIFICATION_UPDATE_QUEUE == null) {
            synchronized (DownloadNotifier.class) {
                if (NOTIFICATION_UPDATE_QUEUE == null) {
                    NOTIFICATION_UPDATE_QUEUE = DispatchThread.create("Notifier");
                }
            }
        }
        return NOTIFICATION_UPDATE_QUEUE;
    }

    DownloadNotifier(Context context, int i) {
        this.mNotificationId = i;
        Runtime instance = Runtime.getInstance();
        String str = TAG;
        instance.log(str, " DownloadNotifier:" + this.mNotificationId);
        this.mContext = context;
        this.mNotificationManager = (NotificationManager) context.getSystemService("notification");
        try {
            if (Build.VERSION.SDK_INT >= 26) {
                Context context2 = this.mContext;
                String concat = context2.getPackageName().concat(".downloader");
                this.mBuilder = new NotificationCompat.Builder(context2, concat);
                NotificationChannel notificationChannel = new NotificationChannel(concat, Runtime.getInstance().getApplicationName(context), 2);
                NotificationManager notificationManager = (NotificationManager) this.mContext.getSystemService("notification");
                if (notificationManager != null) {
                    notificationManager.createNotificationChannel(notificationChannel);
                }
                notificationChannel.enableLights(false);
                notificationChannel.enableVibration(false);
                notificationChannel.setSound(null, null);
                return;
            }
            this.mBuilder = new NotificationCompat.Builder(this.mContext);
        } catch (Throwable th) {
            if (Runtime.getInstance().isDebug()) {
                th.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void initBuilder(DownloadTask downloadTask) {
        String title = getTitle(downloadTask);
        this.mDownloadTask = downloadTask;
        this.mBuilder.setContentIntent(PendingIntent.getActivity(this.mContext, ItemTouchHelper.Callback.DEFAULT_DRAG_ANIMATION_DURATION, new Intent(), Build.VERSION.SDK_INT >= 23 ? 201326592 : 134217728));
        this.mBuilder.setSmallIcon(this.mDownloadTask.getDownloadIcon());
        this.mBuilder.setTicker(this.mContext.getString(R.string.download_trickter));
        this.mBuilder.setContentTitle(title);
        this.mBuilder.setContentText(this.mContext.getString(R.string.download_coming_soon_download));
        this.mBuilder.setWhen(System.currentTimeMillis());
        this.mBuilder.setAutoCancel(true);
        this.mBuilder.setPriority(-1);
        this.mBuilder.setDeleteIntent(buildCancelContent(this.mContext, downloadTask.getId(), downloadTask.getUrl()));
        this.mBuilder.setDefaults(0);
    }

    /* access modifiers changed from: package-private */
    public void updateTitle(DownloadTask downloadTask) {
        this.mBuilder.setContentTitle(getTitle(downloadTask));
    }

    private String getTitle(DownloadTask downloadTask) {
        if (downloadTask.getFile() == null || TextUtils.isEmpty(downloadTask.getFile().getName())) {
            return this.mContext.getString(R.string.download_file_download);
        }
        return downloadTask.getFile().getName();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private PendingIntent buildCancelContent(Context context, int i, String str) {
        Intent intent = new Intent(Runtime.getInstance().append(context, NotificationCancelReceiver.ACTION));
        intent.putExtra("TAG", str);
        int i2 = i * 1000;
        PendingIntent broadcast = PendingIntent.getBroadcast(context, i2, intent, Build.VERSION.SDK_INT >= 23 ? 201326592 : 134217728);
        Runtime instance = Runtime.getInstance();
        String str2 = TAG;
        instance.log(str2, "buildCancelContent id:" + i2 + " cancal action:" + Runtime.getInstance().append(context, NotificationCancelReceiver.ACTION));
        return broadcast;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setProgress(int i, int i2, boolean z) {
        this.mBuilder.setProgress(i, i2, z);
        sent();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean hasDeleteContent() {
        return this.mBuilder.getNotification().deleteIntent != null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setDelecte(PendingIntent pendingIntent) {
        this.mBuilder.getNotification().deleteIntent = pendingIntent;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sent() {
        getNotificationUpdateQueue().post(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass1 */

            public void run() {
                DownloadNotifier downloadNotifier = DownloadNotifier.this;
                downloadNotifier.mNotification = downloadNotifier.mBuilder.build();
                DownloadNotifier.this.mNotificationManager.notify(DownloadNotifier.this.mNotificationId, DownloadNotifier.this.mNotification);
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void onPreDownload() {
        sent();
    }

    /* access modifiers changed from: package-private */
    public void onDownloading(final int i) {
        getNotificationUpdateQueue().postRunnable(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass2 */

            public void run() {
                if (!DownloadNotifier.this.hasDeleteContent()) {
                    DownloadNotifier downloadNotifier = DownloadNotifier.this;
                    downloadNotifier.setDelecte(downloadNotifier.buildCancelContent(downloadNotifier.mContext, DownloadNotifier.this.mNotificationId, DownloadNotifier.this.mDownloadTask.mUrl));
                }
                if (!DownloadNotifier.this.mAddedCancelAction) {
                    DownloadNotifier.this.mAddedCancelAction = true;
                    DownloadNotifier downloadNotifier2 = DownloadNotifier.this;
                    String string = DownloadNotifier.this.mContext.getString(17039360);
                    DownloadNotifier downloadNotifier3 = DownloadNotifier.this;
                    downloadNotifier2.mAction = new NotificationCompat.Action(17170445, string, downloadNotifier3.buildCancelContent(downloadNotifier3.mContext, DownloadNotifier.this.mNotificationId, DownloadNotifier.this.mDownloadTask.mUrl));
                    DownloadNotifier.this.mBuilder.addAction(DownloadNotifier.this.mAction);
                }
                NotificationCompat.Builder builder = DownloadNotifier.this.mBuilder;
                DownloadNotifier downloadNotifier4 = DownloadNotifier.this;
                Context context = downloadNotifier4.mContext;
                int i = R.string.download_current_downloading_progress;
                builder.setContentText(downloadNotifier4.mContent = context.getString(i, i + "%"));
                DownloadNotifier.this.setProgress(100, i, false);
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void onDownloaded(final long j) {
        getNotificationUpdateQueue().postRunnable(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass3 */

            public void run() {
                if (!DownloadNotifier.this.hasDeleteContent()) {
                    DownloadNotifier downloadNotifier = DownloadNotifier.this;
                    downloadNotifier.setDelecte(downloadNotifier.buildCancelContent(downloadNotifier.mContext, DownloadNotifier.this.mNotificationId, DownloadNotifier.this.mDownloadTask.mUrl));
                }
                if (!DownloadNotifier.this.mAddedCancelAction) {
                    DownloadNotifier.this.mAddedCancelAction = true;
                    DownloadNotifier downloadNotifier2 = DownloadNotifier.this;
                    int downloadIcon = DownloadNotifier.this.mDownloadTask.getDownloadIcon();
                    String string = DownloadNotifier.this.mContext.getString(17039360);
                    DownloadNotifier downloadNotifier3 = DownloadNotifier.this;
                    downloadNotifier2.mAction = new NotificationCompat.Action(downloadIcon, string, downloadNotifier3.buildCancelContent(downloadNotifier3.mContext, DownloadNotifier.this.mNotificationId, DownloadNotifier.this.mDownloadTask.mUrl));
                    DownloadNotifier.this.mBuilder.addAction(DownloadNotifier.this.mAction);
                }
                NotificationCompat.Builder builder = DownloadNotifier.this.mBuilder;
                DownloadNotifier downloadNotifier4 = DownloadNotifier.this;
                builder.setContentText(downloadNotifier4.mContent = downloadNotifier4.mContext.getString(R.string.download_current_downloaded_length, DownloadNotifier.byte2FitMemorySize(j)));
                DownloadNotifier.this.setProgress(100, 20, true);
            }
        });
    }

    private long getDelayTime() {
        synchronized (DownloadNotifier.class) {
            long elapsedRealtime = SystemClock.elapsedRealtime();
            long j = sLastUpdateNoticationTime;
            if (elapsedRealtime >= j + 500) {
                sLastUpdateNoticationTime = elapsedRealtime;
                return 0;
            }
            long j2 = 500 - (elapsedRealtime - j);
            sLastUpdateNoticationTime = j + j2;
            return j2;
        }
    }

    /* access modifiers changed from: private */
    public static String byte2FitMemorySize(long j) {
        if (j < 0) {
            return "shouldn't be less than zero!";
        }
        if (j < 1024) {
            return String.format(Locale.getDefault(), "%.1fB", Double.valueOf((double) j));
        } else if (j < 1048576) {
            return String.format(Locale.getDefault(), "%.1fKB", Double.valueOf(((double) j) / 1024.0d));
        } else if (j < 1073741824) {
            return String.format(Locale.getDefault(), "%.1fMB", Double.valueOf(((double) j) / 1048576.0d));
        } else {
            return String.format(Locale.getDefault(), "%.1fGB", Double.valueOf(((double) j) / 1.073741824E9d));
        }
    }

    /* access modifiers changed from: package-private */
    public void onDownloadPaused() {
        Runtime instance = Runtime.getInstance();
        String str = TAG;
        instance.log(str, " onDownloadPaused:" + this.mDownloadTask.getUrl());
        getNotificationUpdateQueue().postRunnable(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass4 */

            public void run() {
                if (!DownloadNotifier.this.hasDeleteContent()) {
                    DownloadNotifier downloadNotifier = DownloadNotifier.this;
                    downloadNotifier.setDelecte(downloadNotifier.buildCancelContent(downloadNotifier.mContext, DownloadNotifier.this.mNotificationId, DownloadNotifier.this.mDownloadTask.mUrl));
                }
                if (TextUtils.isEmpty(DownloadNotifier.this.mContent)) {
                    DownloadNotifier.this.mContent = BuildConfig.FLAVOR;
                }
                DownloadNotifier.this.mBuilder.setContentText(DownloadNotifier.this.mContent.concat("(").concat(DownloadNotifier.this.mContext.getString(R.string.download_paused)).concat(")"));
                DownloadNotifier.this.mBuilder.setSmallIcon(DownloadNotifier.this.mDownloadTask.getDownloadDoneIcon());
                DownloadNotifier.this.removeCancelAction();
                DownloadNotifier.this.mAddedCancelAction = false;
                DownloadNotifier.this.sent();
            }
        }, getDelayTime());
    }

    /* access modifiers changed from: package-private */
    public void onDownloadFinished() {
        final Intent commonFileIntentCompat = Runtime.getInstance().getCommonFileIntentCompat(this.mContext, this.mDownloadTask);
        if (commonFileIntentCompat != null) {
            if (!(this.mContext instanceof Activity)) {
                commonFileIntentCompat.addFlags(268435456);
            }
            getNotificationUpdateQueue().postRunnable(new Runnable() {
                /* class com.download.library.DownloadNotifier.AnonymousClass5 */

                public void run() {
                    DownloadNotifier.this.removeCancelAction();
                    DownloadNotifier.this.setDelecte(null);
                    PendingIntent activity = PendingIntent.getActivity(DownloadNotifier.this.mContext, DownloadNotifier.this.mNotificationId * 10000, commonFileIntentCompat, Build.VERSION.SDK_INT >= 23 ? 201326592 : 134217728);
                    DownloadNotifier.this.mBuilder.setSmallIcon(DownloadNotifier.this.mDownloadTask.getDownloadDoneIcon());
                    DownloadNotifier.this.mBuilder.setContentText(DownloadNotifier.this.mContext.getString(R.string.download_click_open));
                    DownloadNotifier.this.mBuilder.setProgress(100, 100, false);
                    DownloadNotifier.this.mBuilder.setContentIntent(activity);
                    DownloadNotifier.this.sent();
                }
            }, getDelayTime());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void removeCancelAction() {
        int indexOf;
        try {
            Field declaredField = this.mBuilder.getClass().getDeclaredField("mActions");
            ArrayList arrayList = declaredField != null ? (ArrayList) declaredField.get(this.mBuilder) : null;
            if (arrayList != null && (indexOf = arrayList.indexOf(this.mAction)) != -1) {
                arrayList.remove(indexOf);
            }
        } catch (Throwable th) {
            if (Runtime.getInstance().isDebug()) {
                th.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void cancel() {
        final int i = this.mNotificationId;
        getNotificationUpdateQueue().postRunnableScissors(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass6 */

            public void run() {
                DownloadNotifier.this.mNotificationManager.cancel(i);
            }
        });
    }

    static void cancel(final DownloadTask downloadTask) {
        final int i = downloadTask.mId;
        final Context context = downloadTask.getContext();
        final DownloadListener downloadListener = downloadTask.getDownloadListener();
        getNotificationUpdateQueue().postRunnableScissors(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass7 */

            public void run() {
                NotificationManager notificationManager = (NotificationManager) context.getSystemService("notification");
                if (notificationManager != null) {
                    notificationManager.cancel(i);
                }
            }
        });
        GlobalQueue.getMainQueue().post(new Runnable() {
            /* class com.download.library.DownloadNotifier.AnonymousClass8 */

            public void run() {
                DownloadListener downloadListener = DownloadListener.this;
                if (downloadListener != null) {
                    downloadListener.onResult(new DownloadException(Downloader.ERROR_USER_CANCEL, Downloader.DOWNLOAD_MESSAGE.get(Downloader.ERROR_USER_CANCEL)), downloadTask.getFileUri(), downloadTask.getUrl(), downloadTask);
                }
            }
        });
    }
}
