package com.download.library;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Looper;
import android.os.Process;
import android.text.TextUtils;
import android.util.Log;
import com.download.library.DownloadingListener;
import com.queue.library.DispatchThread;
import com.queue.library.GlobalQueue;
import java.io.File;
import java.io.IOException;
import java.util.concurrent.Callable;
import java.util.concurrent.Executor;

public class DownloadSubmitterImpl implements DownloadSubmitter {
    private static final String TAG = "Download-DownloadSubmitterImpl";
    private final Executor mExecutor;
    private final Executor mExecutor0;
    private final Object mLock;
    private volatile DispatchThread mMainQueue;

    private DownloadSubmitterImpl() {
        this.mMainQueue = null;
        this.mLock = new Object();
        this.mExecutor = Executors.taskEnqueueDispatchExecutor();
        this.mExecutor0 = Executors.taskQueuedUpDispatchExecutor();
    }

    static DownloadSubmitterImpl getInstance() {
        return Holder.INSTANCE;
    }

    @Override // com.download.library.DownloadSubmitter
    public boolean submit(DownloadTask downloadTask) {
        if (TextUtils.isEmpty(downloadTask.getUrl())) {
            return false;
        }
        synchronized (this.mLock) {
            if (ExecuteTasksMap.getInstance().exist(downloadTask.getUrl())) {
                String str = TAG;
                Log.e(str, "task exists:" + downloadTask.getUrl());
                return false;
            }
            Downloader downloader = (Downloader) Downloader.create(downloadTask);
            ExecuteTasksMap.getInstance().addTask(downloadTask.getUrl(), downloader);
            execute(new DownloadStartTask(downloadTask, downloader));
            return true;
        }
    }

    @Override // com.download.library.DownloadSubmitter
    public File submit0(DownloadTask downloadTask) throws Exception {
        if (Looper.getMainLooper() != Looper.myLooper()) {
            File file = null;
            if (!submit(downloadTask)) {
                return null;
            }
            downloadTask.setup();
            downloadTask.await();
            if (downloadTask.getThrowable() == null) {
                try {
                    if (downloadTask.isSuccessful()) {
                        file = downloadTask.getFile();
                    }
                    return file;
                } finally {
                    downloadTask.destroy();
                }
            } else {
                throw ((Exception) downloadTask.getThrowable());
            }
        } else {
            throw new RuntimeException("Sync download must call it in the non main-Thread ");
        }
    }

    /* access modifiers changed from: package-private */
    public void execute(final Runnable runnable) {
        this.mExecutor.execute(new Runnable() {
            /* class com.download.library.DownloadSubmitterImpl.AnonymousClass1 */

            public void run() {
                Process.setThreadPriority(10);
                runnable.run();
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void execute0(final Runnable runnable) {
        this.mExecutor0.execute(new Runnable() {
            /* class com.download.library.DownloadSubmitterImpl.AnonymousClass2 */

            public void run() {
                Process.setThreadPriority(10);
                runnable.run();
            }
        });
    }

    /* access modifiers changed from: package-private */
    public DispatchThread getMainQueue() {
        if (this.mMainQueue == null) {
            this.mMainQueue = GlobalQueue.getMainQueue();
        }
        return this.mMainQueue;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void releaseTask(DownloadTask downloadTask) {
        if (!TextUtils.isEmpty(downloadTask.getUrl())) {
            synchronized (this.mLock) {
                if (!TextUtils.isEmpty(downloadTask.getUrl())) {
                    ExecuteTasksMap.getInstance().removeTask(downloadTask.getUrl());
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public class DownloadStartTask implements Runnable {
        private final DownloadTask mDownloadTask;
        private final Downloader mDownloader;

        public DownloadStartTask(DownloadTask downloadTask, Downloader downloader) {
            this.mDownloadTask = downloadTask;
            this.mDownloader = downloader;
        }

        public void run() {
            File file;
            File file2;
            try {
                if (this.mDownloadTask.getDownloadingListener() != null) {
                    try {
                        boolean z = false;
                        if (this.mDownloadTask.getDownloadingListener().getClass().getDeclaredMethod("onProgress", String.class, Long.TYPE, Long.TYPE, Long.TYPE).getAnnotation(DownloadingListener.MainThread.class) != null) {
                            z = true;
                        }
                        this.mDownloader.mCallbackInMainThread = z;
                        Runtime instance = Runtime.getInstance();
                        String str = DownloadSubmitterImpl.TAG;
                        instance.log(str, " callback in main-Thread:" + z);
                    } catch (Exception e) {
                        if (Runtime.getInstance().isDebug()) {
                            e.printStackTrace();
                        }
                    }
                }
                if (this.mDownloadTask.getStatus() != 1004) {
                    this.mDownloadTask.resetTime();
                }
                this.mDownloadTask.setStatus(1001);
                if (this.mDownloadTask.getFile() == null) {
                    if (this.mDownloadTask.isUniquePath()) {
                        file2 = Runtime.getInstance().uniqueFile(this.mDownloadTask, null);
                    } else {
                        file2 = Runtime.getInstance().createFile(this.mDownloadTask.mContext, this.mDownloadTask);
                    }
                    this.mDownloadTask.setFileSafe(file2);
                } else if (this.mDownloadTask.getFile().isDirectory()) {
                    if (this.mDownloadTask.isUniquePath()) {
                        Runtime instance2 = Runtime.getInstance();
                        DownloadTask downloadTask = this.mDownloadTask;
                        file = instance2.uniqueFile(downloadTask, downloadTask.getFile());
                    } else {
                        Runtime instance3 = Runtime.getInstance();
                        Context context = this.mDownloadTask.mContext;
                        DownloadTask downloadTask2 = this.mDownloadTask;
                        file = instance3.createFile(context, downloadTask2, downloadTask2.getFile());
                    }
                    this.mDownloadTask.setFileSafe(file);
                } else if (!this.mDownloadTask.getFile().exists()) {
                    try {
                        this.mDownloadTask.getFile().createNewFile();
                    } catch (IOException e2) {
                        e2.printStackTrace();
                        this.mDownloadTask.setFileSafe(null);
                    }
                }
                if (this.mDownloadTask.getFile() != null) {
                    this.mDownloadTask.createNotifier();
                    if (this.mDownloadTask.isParallelDownload()) {
                        executeOnExecutor(Executors.io());
                    } else {
                        executeOnExecutor(Executors.getSerialExecutor());
                    }
                } else {
                    throw new RuntimeException("target file can't be created . ");
                }
            } catch (Throwable th) {
                DownloadSubmitterImpl.this.releaseTask(this.mDownloadTask);
                th.printStackTrace();
                throw th;
            }
        }

        private void executeOnExecutor(Executor executor) {
            executor.execute(new Runnable() {
                /* class com.download.library.DownloadSubmitterImpl.DownloadStartTask.AnonymousClass1 */

                public void run() {
                    try {
                        DownloadSubmitterImpl.getInstance().execute0(new DownloadTaskOver(DownloadStartTask.this.mDownloader.doInBackground().intValue(), DownloadStartTask.this.mDownloader, DownloadStartTask.this.mDownloadTask));
                    } catch (Throwable th) {
                        th.printStackTrace();
                        DownloadStartTask.this.mDownloadTask.error();
                        DownloadSubmitterImpl.this.releaseTask(DownloadStartTask.this.mDownloadTask);
                    }
                }
            });
        }
    }

    /* access modifiers changed from: private */
    public final class DownloadTaskOver implements Runnable {
        private final DownloadNotifier mDownloadNotifier;
        private final DownloadTask mDownloadTask;
        private final Downloader mDownloader;
        private final int mResult;

        DownloadTaskOver(int i, Downloader downloader, DownloadTask downloadTask) {
            this.mResult = i;
            this.mDownloader = downloader;
            this.mDownloadTask = downloadTask;
            this.mDownloadNotifier = downloadTask.mDownloadNotifier;
        }

        public void run() {
            DownloadTask downloadTask = this.mDownloadTask;
            try {
                int i = this.mResult;
                if (i == 16388) {
                    DownloadNotifier downloadNotifier = this.mDownloadNotifier;
                    if (downloadNotifier != null) {
                        downloadNotifier.onDownloadPaused();
                    }
                } else {
                    if (i == 16390) {
                        downloadTask.completed();
                    } else if (i == 16393) {
                        downloadTask.completed();
                    } else {
                        downloadTask.completed();
                    }
                    boolean doCallback = doCallback(Integer.valueOf(this.mResult));
                    if (this.mResult > 8192) {
                        DownloadNotifier downloadNotifier2 = this.mDownloadNotifier;
                        if (downloadNotifier2 != null) {
                            downloadNotifier2.cancel();
                        }
                    } else {
                        if (downloadTask.isEnableIndicator()) {
                            if (doCallback) {
                                DownloadNotifier downloadNotifier3 = this.mDownloadNotifier;
                                if (downloadNotifier3 != null) {
                                    downloadNotifier3.cancel();
                                }
                            } else {
                                DownloadNotifier downloadNotifier4 = this.mDownloadNotifier;
                                if (downloadNotifier4 != null) {
                                    downloadNotifier4.onDownloadFinished();
                                }
                            }
                        }
                        if (downloadTask.isAutoOpen()) {
                            autoOpen();
                            DownloadSubmitterImpl.this.releaseTask(downloadTask);
                            destroyTask();
                            downloadTask.anotify();
                            return;
                        }
                    }
                }
                DownloadSubmitterImpl.this.releaseTask(downloadTask);
                destroyTask();
                downloadTask.anotify();
            } catch (Throwable th) {
                DownloadSubmitterImpl.this.releaseTask(downloadTask);
                destroyTask();
                downloadTask.anotify();
                throw th;
            }
        }

        /* access modifiers changed from: package-private */
        public void destroyTask() {
            DownloadTask downloadTask = this.mDownloadTask;
            if (downloadTask.isSuccessful() && !downloadTask.isAWait) {
                Runtime instance = Runtime.getInstance();
                String str = DownloadSubmitterImpl.TAG;
                instance.log(str, "destroyTask:" + downloadTask.getUrl());
                downloadTask.destroy();
            }
        }

        private void autoOpen() {
            DownloadSubmitterImpl.this.getMainQueue().postRunnableScissors(new Runnable() {
                /* class com.download.library.DownloadSubmitterImpl.DownloadTaskOver.AnonymousClass1 */

                public void run() {
                    Intent commonFileIntentCompat = Runtime.getInstance().getCommonFileIntentCompat(DownloadTaskOver.this.mDownloadTask.getContext(), DownloadTaskOver.this.mDownloadTask);
                    if (!(DownloadTaskOver.this.mDownloadTask.getContext() instanceof Activity)) {
                        commonFileIntentCompat.addFlags(268435456);
                    }
                    try {
                        DownloadTaskOver.this.mDownloadTask.getContext().startActivity(commonFileIntentCompat);
                    } catch (Throwable th) {
                        if (Runtime.getInstance().isDebug()) {
                            th.printStackTrace();
                        }
                    }
                }
            });
        }

        private boolean doCallback(final Integer num) {
            final DownloadTask downloadTask = this.mDownloadTask;
            final DownloadListener downloadListener = downloadTask.getDownloadListener();
            if (downloadListener == null) {
                return false;
            }
            return ((Boolean) DownloadSubmitterImpl.getInstance().getMainQueue().call(new Callable<Boolean>() {
                /* class com.download.library.DownloadSubmitterImpl.DownloadTaskOver.AnonymousClass2 */

                @Override // java.util.concurrent.Callable
                public Boolean call() {
                    DownloadException downloadException;
                    DownloadListener downloadListener = downloadListener;
                    if (num.intValue() <= 8192) {
                        downloadException = null;
                    } else {
                        int intValue = num.intValue();
                        downloadException = new DownloadException(intValue, "failed , cause:" + Downloader.DOWNLOAD_MESSAGE.get(num.intValue()));
                    }
                    return Boolean.valueOf(downloadListener.onResult(downloadException, downloadTask.getFileUri(), downloadTask.getUrl(), DownloadTaskOver.this.mDownloadTask));
                }
            })).booleanValue();
        }
    }

    /* access modifiers changed from: private */
    public static class Holder {
        private static final DownloadSubmitterImpl INSTANCE = new DownloadSubmitterImpl();

        private Holder() {
        }
    }
}
