package com.download.library;

import android.content.Context;
import android.net.Uri;
import android.os.SystemClock;
import android.text.TextUtils;
import com.queue.library.BuildConfig;
import com.queue.library.GlobalQueue;
import java.io.File;
import java.io.IOException;
import java.io.Serializable;
import java.util.HashMap;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

public class DownloadTask extends Extra implements Serializable, Cloneable {
    public static final int STATUS_CANCELED = 1006;
    public static final int STATUS_DOWNLOADING = 1002;
    public static final int STATUS_ERROR = 1007;
    public static final int STATUS_NEW = 1000;
    public static final int STATUS_PAUSED = 1004;
    public static final int STATUS_PAUSING = 1003;
    public static final int STATUS_PENDDING = 1001;
    public static final int STATUS_SUCCESSFUL = 1005;
    static final String TAG = "Download-DownloadTask";
    protected String authority = BuildConfig.FLAVOR;
    long beginTime = 0;
    int connectTimes = 0;
    long detalTime = 0;
    long endTime = 0;
    volatile boolean isAWait = false;
    boolean isCustomFile = false;
    volatile long loaded = 0;
    Condition mCondition = null;
    protected Context mContext;
    protected DownloadListener mDownloadListener;
    protected DownloadNotifier mDownloadNotifier;
    DownloadStatusListener mDownloadStatusListener;
    protected DownloadingListener mDownloadingListener;
    protected File mFile;
    int mId = Runtime.getInstance().generateGlobalId();
    Throwable mThrowable;
    long mTotalsLength;
    Lock mutex = null;
    long pauseTime = 0;
    String redirect = BuildConfig.FLAVOR;
    private volatile int status = 1000;
    boolean uniquePath = true;

    /* access modifiers changed from: protected */
    public synchronized void setup() {
        if (this.mutex == null) {
            ReentrantLock reentrantLock = new ReentrantLock();
            this.mutex = reentrantLock;
            this.mCondition = reentrantLock.newCondition();
        }
    }

    /* access modifiers changed from: package-private */
    public void resetConnectTimes() {
        this.connectTimes = 0;
    }

    public synchronized int getStatus() {
        return this.status;
    }

    /* access modifiers changed from: package-private */
    public synchronized void setStatus(final int i) {
        this.status = i;
        final DownloadStatusListener downloadStatusListener = this.mDownloadStatusListener;
        if (downloadStatusListener != null) {
            GlobalQueue.getMainQueue().postRunnable(new Runnable() {
                /* class com.download.library.DownloadTask.AnonymousClass1 */

                public void run() {
                    downloadStatusListener.onDownloadStatusChanged(this.clone(), i);
                }
            });
        }
    }

    /* access modifiers changed from: package-private */
    public void resetTime() {
        this.beginTime = 0;
        this.pauseTime = 0;
        this.endTime = 0;
        this.detalTime = 0;
    }

    public int getId() {
        return this.mId;
    }

    public Context getContext() {
        return this.mContext;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setContext(Context context) {
        this.mContext = context.getApplicationContext();
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setEnableIndicator(boolean z) {
        if (!z || this.mFile == null || !TextUtils.isEmpty(this.authority)) {
            this.mEnableIndicator = z;
        } else {
            Runtime.getInstance().logError(TAG, "Custom file path, you must specify authority, otherwise the notification should not be turned on. ");
            this.mEnableIndicator = false;
        }
        return this;
    }

    public File getFile() {
        return this.mFile;
    }

    public Uri getFileUri() {
        return Uri.fromFile(this.mFile);
    }

    /* access modifiers changed from: package-private */
    public String getAuthority() {
        return this.authority;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask setFileSafe(File file) {
        this.mFile = file;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setFile(File file) {
        this.mFile = file;
        this.authority = BuildConfig.FLAVOR;
        checkCustomFilePath(file);
        return this;
    }

    private void checkCustomFilePath(File file) {
        if (file == null || file.getAbsolutePath().startsWith(Runtime.getInstance().getDefaultDir(getContext()).getAbsolutePath())) {
            this.isCustomFile = false;
        } else if (!TextUtils.isEmpty(this.authority)) {
            setEnableIndicator(true);
            this.isCustomFile = true;
        } else {
            setEnableIndicator(false);
            this.isCustomFile = true;
        }
    }

    /* access modifiers changed from: package-private */
    public boolean isCustomFile() {
        return this.isCustomFile;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setFile(File file, String str) {
        if (!file.exists() && file.isFile()) {
            try {
                file.createNewFile();
            } catch (IOException e) {
                e.printStackTrace();
                Runtime.getInstance().logError(TAG, "create file error .");
                return this;
            }
        }
        this.mFile = file;
        this.authority = str;
        checkCustomFilePath(file);
        return this;
    }

    /* access modifiers changed from: package-private */
    public void updateTime(long j) {
        long j2 = this.beginTime;
        if (j2 == 0) {
            this.beginTime = j;
        } else if (j2 != j) {
            this.detalTime += Math.abs(j - this.pauseTime);
        }
    }

    public long getUsedTime() {
        long j;
        long j2;
        if (this.status != 1002) {
            if (this.status == 1006) {
                j = this.endTime - this.beginTime;
                j2 = this.detalTime;
            } else if (this.status == 1001) {
                long j3 = this.pauseTime;
                if (j3 > 0) {
                    return (j3 - this.beginTime) - this.detalTime;
                }
                return 0;
            } else if (this.status == 1004 || this.status == 1003) {
                j = this.pauseTime - this.beginTime;
                j2 = this.detalTime;
            } else if (this.status == 1000) {
                long j4 = this.pauseTime;
                if (j4 > 0) {
                    return (j4 - this.beginTime) - this.detalTime;
                }
                return 0;
            } else if (this.status != 1005 && this.status != 1007) {
                return 0;
            } else {
                j = this.endTime - this.beginTime;
                j2 = this.detalTime;
            }
            return j - j2;
        } else if (this.beginTime > 0) {
            return (SystemClock.elapsedRealtime() - this.beginTime) - this.detalTime;
        } else {
            return 0;
        }
    }

    public boolean isPausing() {
        return getStatus() == 1003;
    }

    public void pausing() {
        setStatus(1003);
        this.pauseTime = SystemClock.elapsedRealtime();
    }

    public boolean isPaused() {
        return getStatus() == 1004;
    }

    public boolean isCanceled() {
        return getStatus() == 1006;
    }

    public long getBeginTime() {
        return this.beginTime;
    }

    /* access modifiers changed from: protected */
    public void pause() {
        this.pauseTime = SystemClock.elapsedRealtime();
        this.connectTimes = 0;
        setStatus(1004);
    }

    /* access modifiers changed from: protected */
    public void cancel() {
        this.endTime = SystemClock.elapsedRealtime();
        setStatus(1006);
    }

    /* access modifiers changed from: protected */
    public void error() {
        this.endTime = SystemClock.elapsedRealtime();
        setStatus(1007);
    }

    /* access modifiers changed from: protected */
    public void successful() {
        this.endTime = SystemClock.elapsedRealtime();
        setStatus(STATUS_SUCCESSFUL);
    }

    /* access modifiers changed from: protected */
    public void setCalculateMD5(boolean z) {
        this.calculateMD5 = z;
    }

    /* access modifiers changed from: package-private */
    public boolean isSuccessful() {
        return getStatus() == 1005;
    }

    /* access modifiers changed from: protected */
    public void completed() {
        this.endTime = SystemClock.elapsedRealtime();
    }

    /* access modifiers changed from: protected */
    public void destroy() {
        this.mId = -1;
        this.mUrl = null;
        this.mContext = null;
        this.mFile = null;
        this.mIsParallelDownload = false;
        this.mIsForceDownload = false;
        this.mEnableIndicator = true;
        this.mDownloadIcon = 17301633;
        this.mDownloadDoneIcon = 17301634;
        this.mIsParallelDownload = true;
        this.mIsBreakPointDownload = true;
        this.mUserAgent = BuildConfig.FLAVOR;
        this.mContentDisposition = BuildConfig.FLAVOR;
        this.mMimetype = BuildConfig.FLAVOR;
        this.mContentLength = -1;
        if (this.mHeaders != null) {
            this.mHeaders.clear();
            this.mHeaders = null;
        }
        this.retry = 3;
        this.fileMD5 = BuildConfig.FLAVOR;
        this.targetCompareMD5 = BuildConfig.FLAVOR;
        this.calculateMD5 = false;
    }

    /* access modifiers changed from: package-private */
    public DownloadingListener getDownloadingListener() {
        return this.mDownloadingListener;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setDownloadingListener(DownloadingListener downloadingListener) {
        this.mDownloadingListener = downloadingListener;
        return this;
    }

    public DownloadListener getDownloadListener() {
        return this.mDownloadListener;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setDownloadListener(DownloadListener downloadListener) {
        this.mDownloadListener = downloadListener;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setDownloadListenerAdapter(DownloadListenerAdapter downloadListenerAdapter) {
        setDownloadListener(downloadListenerAdapter);
        setDownloadingListener(downloadListenerAdapter);
        setDownloadStatusListener(downloadListenerAdapter);
        return this;
    }

    /* access modifiers changed from: package-private */
    public void setTotalsLength(long j) {
        this.mTotalsLength = j;
    }

    public long getTotalsLength() {
        return this.mTotalsLength;
    }

    public long getLoaded() {
        return this.loaded;
    }

    /* access modifiers changed from: package-private */
    public void setLoaded(long j) {
        this.loaded = j;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setBreakPointDownload(boolean z) {
        this.mIsBreakPointDownload = z;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setForceDownload(boolean z) {
        this.mIsForceDownload = z;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setIcon(int i) {
        this.mDownloadIcon = i;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setParallelDownload(boolean z) {
        this.mIsParallelDownload = z;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask addHeader(String str, String str2) {
        if (this.mHeaders == null) {
            this.mHeaders = new HashMap();
        }
        this.mHeaders.put(str, str2);
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask autoOpenIgnoreMD5() {
        this.mAutoOpen = true;
        if (this.mFile != null && TextUtils.isEmpty(this.authority)) {
            Runtime.getInstance().logError(TAG, "Custom file path, you must specify authority, otherwise the auto open should be closed. ");
            this.mAutoOpen = false;
        }
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask autoOpenWithMD5(String str) {
        if (TextUtils.isEmpty(str)) {
            return this;
        }
        this.mAutoOpen = true;
        if (this.mFile != null && TextUtils.isEmpty(this.authority)) {
            Runtime.getInstance().logError(TAG, "Custom file path, you must specify authority, otherwise the auto open should be closed. ");
            this.mAutoOpen = false;
        }
        this.targetCompareMD5 = str;
        this.calculateMD5 = true;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask closeAutoOpen() {
        this.mAutoOpen = false;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setDownloadTimeOut(long j) {
        this.downloadTimeOut = j;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setConnectTimeOut(long j) {
        this.connectTimeOut = j;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setBlockMaxTime(long j) {
        this.blockMaxTime = j;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setUserAgent(String str) {
        this.mUserAgent = str;
        return this;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask setContentLength(long j) {
        this.mContentLength = j;
        return this;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask setMimetype(String str) {
        this.mMimetype = str;
        return this;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask setContentDisposition(String str) {
        this.mContentDisposition = str;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setUrl(String str) {
        this.mUrl = str;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setDownloadDoneIcon(int i) {
        this.mDownloadDoneIcon = i;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setQuickProgress(boolean z) {
        this.quickProgress = z;
        return this;
    }

    /* access modifiers changed from: protected */
    public DownloadTask setTargetCompareMD5(String str) {
        this.targetCompareMD5 = str;
        if (!TextUtils.isEmpty(this.targetCompareMD5)) {
            this.calculateMD5 = true;
        }
        return this;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask setFileMD5(String str) {
        this.fileMD5 = str;
        return this;
    }

    @Override // com.download.library.Extra
    public String getFileMD5() {
        if (TextUtils.isEmpty(this.fileMD5)) {
            this.fileMD5 = Runtime.getInstance().md5(this.mFile);
            if (this.fileMD5 == null) {
                this.fileMD5 = BuildConfig.FLAVOR;
            }
        }
        return super.getFileMD5();
    }

    /* access modifiers changed from: protected */
    public DownloadTask setRetry(int i) {
        if (i > 5) {
            i = 5;
        }
        if (i < 0) {
            i = 0;
        }
        this.retry = i;
        return this;
    }

    /* access modifiers changed from: protected */
    public void createNotifier() {
        DownloadNotifier downloadNotifier = this.mDownloadNotifier;
        if (downloadNotifier != null) {
            downloadNotifier.initBuilder(this);
        } else {
            Context applicationContext = getContext().getApplicationContext();
            if (applicationContext != null && isEnableIndicator()) {
                DownloadNotifier downloadNotifier2 = new DownloadNotifier(applicationContext, getId());
                this.mDownloadNotifier = downloadNotifier2;
                downloadNotifier2.initBuilder(this);
            }
        }
        DownloadNotifier downloadNotifier3 = this.mDownloadNotifier;
        if (downloadNotifier3 != null) {
            downloadNotifier3.onPreDownload();
        }
    }

    /* access modifiers changed from: package-private */
    public boolean isDataURI() {
        return !TextUtils.isEmpty(this.mUrl) && this.mUrl.startsWith("data");
    }

    /* access modifiers changed from: package-private */
    public String getRedirect() {
        return this.redirect;
    }

    /* access modifiers changed from: package-private */
    public void setRedirect(String str) {
        this.redirect = str;
    }

    @Override // java.lang.Object
    public DownloadTask clone() {
        try {
            DownloadTask downloadTask = new DownloadTask();
            copy(downloadTask);
            return downloadTask;
        } catch (Throwable th) {
            th.printStackTrace();
            return new DownloadTask();
        }
    }

    /* access modifiers changed from: package-private */
    public boolean isCompleted() {
        int status2 = getStatus();
        return status2 == 1006 || status2 == 1004 || status2 == 1005 || status2 == 1007;
    }

    public boolean isUniquePath() {
        return this.uniquePath;
    }

    /* access modifiers changed from: protected */
    public void setUniquePath(boolean z) {
        this.uniquePath = z;
    }

    public DownloadStatusListener getDownloadStatusListener() {
        return this.mDownloadStatusListener;
    }

    /* access modifiers changed from: package-private */
    public void setDownloadStatusListener(DownloadStatusListener downloadStatusListener) {
        this.mDownloadStatusListener = downloadStatusListener;
    }

    /* access modifiers changed from: package-private */
    public Throwable getThrowable() {
        return this.mThrowable;
    }

    /* access modifiers changed from: package-private */
    public void setThrowable(Throwable th) {
        this.mThrowable = th;
    }

    /* access modifiers changed from: package-private */
    public void await() throws InterruptedException {
        Lock lock = this.mutex;
        if (lock != null) {
            lock.lock();
            while (!isCompleted()) {
                try {
                    this.isAWait = true;
                    this.mCondition.await();
                } finally {
                    this.mutex.unlock();
                    this.isAWait = false;
                }
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void anotify() {
        Lock lock = this.mutex;
        if (lock != null) {
            lock.lock();
            try {
                this.mCondition.signalAll();
            } finally {
                this.mutex.unlock();
            }
        }
    }
}
