package com.download.library;

import android.os.Handler;
import android.os.Looper;
import android.os.StatFs;
import android.os.SystemClock;
import android.text.TextUtils;
import android.util.Base64;
import android.util.SparseArray;
import androidx.constraintlayout.core.motion.utils.TypedValues;
import com.just.agentweb.AgentWebPermissions;
import com.queue.library.BuildConfig;
import java.io.BufferedInputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Map;
import java.util.zip.GZIPInputStream;
import java.util.zip.Inflater;
import java.util.zip.InflaterInputStream;

public class Downloader extends AsyncTask implements IDownloader<DownloadTask>, ExecuteTask {
    private static final int BUFFER_SIZE = 8192;
    protected static final SparseArray<String> DOWNLOAD_MESSAGE;
    public static final int ERROR_LOAD = 16393;
    public static final int ERROR_MD5 = 16401;
    public static final int ERROR_NETWORK_CONNECTION = 16384;
    public static final int ERROR_RESOURCE_NOT_FOUND = 16400;
    public static final int ERROR_RESPONSE_STATUS = 16385;
    public static final int ERROR_SERVICE = 20483;
    public static final int ERROR_SHUTDOWN = 16391;
    public static final int ERROR_STORAGE = 16386;
    public static final int ERROR_TIME_OUT = 16387;
    public static final int ERROR_TOO_MANY_REDIRECTS = 16392;
    public static final int ERROR_USER_CANCEL = 16390;
    public static final int ERROR_USER_PAUSE = 16388;
    private static final Handler HANDLER = new Handler(Looper.getMainLooper());
    public static final int HTTP_RANGE_NOT_SATISFIABLE = 4016;
    private static final int HTTP_TEMP_REDIRECT = 307;
    private static final int MAX_REDIRECTS = 7;
    public static final int SUCCESSFUL = 8192;
    private static final String TAG = "Download-Downloader";
    protected volatile boolean enableProgress = false;
    private volatile long mAverageSpeed = 0;
    private volatile long mBeginTime = 0;
    protected boolean mCallbackInMainThread = false;
    protected long mConnectTimeOut = 10000;
    private StringBuffer mDownloadMessage = new StringBuffer();
    protected volatile DownloadTask mDownloadTask;
    protected long mDownloadTimeOut = Long.MAX_VALUE;
    private long mLastLoaded = 0;
    private long mLastTime = 0;
    private volatile long mLoaded = 0;
    protected volatile Throwable mThrowable;
    protected volatile long mTotals = -1;
    private long mUsedTime = 0;
    protected boolean quickProgress = false;

    @Override // com.download.library.IDownloader
    public boolean download(DownloadTask downloadTask) {
        return true;
    }

    static /* synthetic */ long access$014(Downloader downloader, long j) {
        long j2 = downloader.mLoaded + j;
        downloader.mLoaded = j2;
        return j2;
    }

    static {
        SparseArray<String> sparseArray = new SparseArray<>(13);
        DOWNLOAD_MESSAGE = sparseArray;
        sparseArray.append(16384, "Network connection error . ");
        sparseArray.append(ERROR_RESPONSE_STATUS, "Response code non-200 or non-206 . ");
        sparseArray.append(16386, "Insufficient memory space . ");
        sparseArray.append(ERROR_SHUTDOWN, "Shutdown . ");
        sparseArray.append(ERROR_TIME_OUT, "Download time is overtime . ");
        sparseArray.append(ERROR_USER_CANCEL, "The user canceled the download . ");
        sparseArray.append(ERROR_RESOURCE_NOT_FOUND, "Resource not found . ");
        sparseArray.append(ERROR_USER_PAUSE, "paused . ");
        sparseArray.append(ERROR_LOAD, "IO Error . ");
        sparseArray.append(ERROR_SERVICE, "Service Unavailable . ");
        sparseArray.append(ERROR_TOO_MANY_REDIRECTS, "Too many redirects . ");
        sparseArray.append(ERROR_MD5, "Md5 check fails . ");
        sparseArray.append(8192, "Download successful . ");
    }

    protected Downloader() {
    }

    static ExecuteTask create(DownloadTask downloadTask) {
        Downloader downloader = new Downloader();
        downloader.mDownloadTask = downloadTask;
        downloader.mTotals = downloadTask.getTotalsLength();
        downloader.mDownloadTimeOut = downloadTask.getDownloadTimeOut();
        downloader.mConnectTimeOut = downloadTask.getConnectTimeOut();
        downloader.quickProgress = downloadTask.isQuickProgress();
        downloader.enableProgress = downloadTask.isEnableIndicator() || downloadTask.getDownloadingListener() != null;
        return downloader;
    }

    /* access modifiers changed from: package-private */
    public void checkIsNullTask(DownloadTask downloadTask) {
        if (downloadTask == null) {
            throw new NullPointerException("downloadTask can't be null.");
        } else if (downloadTask.getContext() == null) {
            throw new NullPointerException("context can't be null.");
        }
    }

    private boolean checkSpace() {
        DownloadTask downloadTask = this.mDownloadTask;
        if (downloadTask.getTotalsLength() - downloadTask.getFile().length() <= getFsAvailableSize(downloadTask.getFile().getParent()) - 104857600) {
            return true;
        }
        Runtime.getInstance().logError(TAG, " 空间不足");
        return false;
    }

    public static long getFsAvailableSize(String str) {
        if (TextUtils.isEmpty(str)) {
            return 0;
        }
        try {
            StatFs statFs = new StatFs(str);
            return statFs.getBlockSizeLong() * statFs.getAvailableBlocksLong();
        } catch (Throwable th) {
            th.printStackTrace();
            return 0;
        }
    }

    private boolean checkNet() {
        DownloadTask downloadTask = this.mDownloadTask;
        if (!downloadTask.isForceDownload()) {
            return Runtime.getInstance().checkWifi(downloadTask.getContext());
        }
        return Runtime.getInstance().checkNetwork(downloadTask.getContext());
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: protected */
    public Integer doInBackground() {
        String str = BuildConfig.FLAVOR;
        DownloadTask downloadTask = this.mDownloadTask;
        boolean isPausing = downloadTask.isPausing();
        Integer valueOf = Integer.valueOf((int) ERROR_USER_PAUSE);
        if (isPausing) {
            downloadTask.pause();
            return valueOf;
        } else if (downloadTask.isPaused()) {
            return valueOf;
        } else {
            if (downloadTask.isCanceled()) {
                return Integer.valueOf((int) ERROR_USER_CANCEL);
            }
            if (downloadTask.isDataURI()) {
                return Integer.valueOf(transferDataFromUrl());
            }
            this.mBeginTime = SystemClock.elapsedRealtime();
            if (!checkNet()) {
                Runtime instance = Runtime.getInstance();
                String str2 = TAG;
                instance.logError(str2, " Network error,isForceDownload:" + this.mDownloadTask.isForceDownload());
                downloadTask.error();
                return 16384;
            }
            this.mDownloadMessage.append("\r\n").append("=============").append("\n");
            this.mDownloadMessage.append("Download Message").append("\n");
            this.mDownloadMessage.append("downloadTask id=").append(downloadTask.getId()).append("\n");
            this.mDownloadMessage.append("url=").append(downloadTask.getUrl()).append("\n");
            try {
                this.mDownloadMessage.append("file=").append(downloadTask.getFile() == null ? str : downloadTask.getFile().getCanonicalPath()).append("\n");
            } catch (IOException e) {
                e.printStackTrace();
            }
            String name = Thread.currentThread().getName();
            Thread currentThread = Thread.currentThread();
            currentThread.setName("pool-download-thread-" + Runtime.getInstance().generateGlobalThreadId());
            try {
                downloadTask.setStatus(1002);
                IOException e2 = null;
                int i = 0;
                int i2 = ERROR_LOAD;
                while (i <= downloadTask.retry) {
                    try {
                        i2 = doDownload();
                    } catch (IOException e3) {
                        e2 = e3;
                        this.mThrowable = e2;
                        if (Runtime.getInstance().isDebug()) {
                            e2.printStackTrace();
                        }
                        i2 = ERROR_LOAD;
                    }
                    if (e2 != null) {
                        if (i == downloadTask.retry) {
                            downloadTask.error();
                            this.mDownloadTask.setThrowable(e2);
                        }
                        this.mDownloadMessage.append("download error message: ").append(e2.getMessage()).append("\n");
                        i++;
                        if (i <= downloadTask.retry) {
                            this.mDownloadMessage.append("download error , retry ").append(i).append("\n");
                        }
                    }
                }
                try {
                    StringBuffer append = this.mDownloadMessage.append("final output file=");
                    if (downloadTask.getFile() != null) {
                        str = downloadTask.getFile().getCanonicalPath();
                    }
                    append.append(str).append("\n");
                } catch (IOException e4) {
                    e4.printStackTrace();
                }
                if (downloadTask.getHeaders() != null && !downloadTask.getHeaders().isEmpty()) {
                    this.mDownloadMessage.append("custom request headers=").append(downloadTask.getHeaders().toString()).append("\n");
                }
                StringBuffer append2 = this.mDownloadMessage.append("error=");
                append2.append("0x" + Integer.toHexString(i2)).append("\n");
                this.mDownloadMessage.append("error table: ERROR_NETWORK_CONNECTION = 0x4000,ERROR_RESPONSE_STATUS = 0x4001,ERROR_STORAGE = 0x4002,ERROR_TIME_OUT = 0x4003,ERROR_USER_PAUSE = 0x4004,ERROR_USER_CANCEL = 0x4006,ERROR_SHUTDOWN = 0x4007,ERROR_TOO_MANY_REDIRECTS = 0x4008,ERROR_LOAD = 0x4009,ERROR_RESOURCE_NOT_FOUND = 0x4010,ERROR_MD5 = 0x4011,ERROR_SERVICE = 0x5003,SUCCESSFUL = 0x2000,HTTP_RANGE_NOT_SATISFIABLE = 4016").append("\n");
                this.mDownloadMessage.append("error message=").append(DOWNLOAD_MESSAGE.get(i2)).append("\n");
                this.mDownloadMessage.append("mLoaded=").append(this.mLoaded).append("\n");
                this.mDownloadMessage.append("mLastLoaded=").append(this.mLastLoaded).append("\n");
                this.mDownloadMessage.append("mLoaded+mLastLoaded=").append(this.mLoaded + this.mLastLoaded).append("\n");
                this.mDownloadMessage.append("totals=").append(this.mTotals).append("\n");
                if (downloadTask.getStatus() == 1005 || i2 == 16401) {
                    this.mDownloadMessage.append("isCalculateMD5=").append(downloadTask.isCalculateMD5()).append("\n");
                    if (!TextUtils.isEmpty(downloadTask.fileMD5)) {
                        this.mDownloadMessage.append("FileMD5=").append(downloadTask.fileMD5).append("\n");
                    } else {
                        this.mDownloadMessage.append("FileMD5=").append("''").append("\n");
                    }
                }
                if (!TextUtils.isEmpty(downloadTask.getTargetCompareMD5())) {
                    this.mDownloadMessage.append("targetCompareMD5=").append(downloadTask.getTargetCompareMD5()).append("\n");
                }
                this.mDownloadMessage.append("current downloadTask status=").append(downloadTask.getStatus()).append("\n");
                this.mDownloadMessage.append("status table: STATUS_NEW = 1000,STATUS_PENDDING = 1001,STATUS_DOWNLOADING = 1002,STATUS_PAUSING = 1003,STATUS_PAUSED = 1004,STATUS_SUCCESSFUL = 1005,STATUS_CANCELED = 1006,STATUS_ERROR = 1007").append("\n");
                this.mDownloadMessage.append("used time=").append(downloadTask.getUsedTime()).append("ms").append("\n");
                this.mDownloadMessage.append("\r\n");
                Runtime instance2 = Runtime.getInstance();
                String str3 = TAG;
                instance2.log(str3, "\r\n" + this.mDownloadMessage.toString());
                Thread.currentThread().setName(name);
                return Integer.valueOf(i2);
            } catch (Throwable th) {
                Thread.currentThread().setName(name);
                throw th;
            }
        }
    }

    private int transferDataFromUrl() {
        Throwable th;
        IOException e;
        DownloadTask downloadTask = this.mDownloadTask;
        String url = downloadTask.getUrl();
        if (!url.startsWith("data") || !url.contains(",")) {
            return ERROR_LOAD;
        }
        String extractContent = extractContent();
        if (TextUtils.isEmpty(extractContent)) {
            return ERROR_LOAD;
        }
        byte[] decode = Base64.decode(extractContent, 0);
        downloadTask.setContentLength((long) decode.length);
        downloadTask.setTotalsLength((long) decode.length);
        Closeable closeable = null;
        try {
            LoadingRandomAccessFile loadingRandomAccessFile = new LoadingRandomAccessFile(downloadTask.getFile());
            try {
                loadingRandomAccessFile.seek(0);
                loadingRandomAccessFile.write(decode);
                progressFinaly();
                closeIO(loadingRandomAccessFile);
                return 8192;
            } catch (IOException e2) {
                e = e2;
                closeable = loadingRandomAccessFile;
                try {
                    e.printStackTrace();
                    progressFinaly();
                    closeIO(closeable);
                    return 8192;
                } catch (Throwable th2) {
                    th = th2;
                    progressFinaly();
                    closeIO(closeable);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                closeable = loadingRandomAccessFile;
                progressFinaly();
                closeIO(closeable);
                throw th;
            }
        } catch (IOException e3) {
            e = e3;
            e.printStackTrace();
            progressFinaly();
            closeIO(closeable);
            return 8192;
        }
    }

    /* access modifiers changed from: package-private */
    public String extractContent() {
        String str;
        int indexOf;
        int i;
        DownloadTask downloadTask = this.mDownloadTask;
        if (!downloadTask.isDataURI() || (indexOf = (str = downloadTask.mUrl).indexOf(",", 5)) <= 5) {
            return BuildConfig.FLAVOR;
        }
        int i2 = indexOf;
        while (true) {
            if (i2 < 5) {
                i = -1;
                break;
            }
            String valueOf = String.valueOf(str.charAt(i2));
            if (valueOf.equals(";") || valueOf.equals(":")) {
                i = i2 + 1;
            } else {
                i2--;
            }
        }
        i = i2 + 1;
        String substring = str.substring(i, indexOf);
        if (substring.equalsIgnoreCase("base64")) {
            return str.substring(str.indexOf(",", 5) + 1);
        }
        Runtime.getInstance().log(TAG, "unsupport chartset:" + substring);
        return BuildConfig.FLAVOR;
    }

    private int doDownload() throws IOException {
        URL url;
        boolean z;
        long headerFieldLong;
        String str;
        String str2 = "range not satisfiable .";
        DownloadTask downloadTask = this.mDownloadTask;
        downloadTask.updateTime(this.mBeginTime);
        downloadTask.resetConnectTimes();
        if (TextUtils.isEmpty(downloadTask.redirect)) {
            url = new URL(downloadTask.getUrl());
        } else {
            url = new URL(downloadTask.getRedirect());
        }
        HttpURLConnection httpURLConnection = null;
        URL url2 = url;
        int i = 0;
        while (true) {
            int i2 = i + 1;
            if (i <= 7) {
                try {
                    this.mDownloadMessage.append("redirectionCount=").append(i2).append("\n");
                    if (downloadTask.connectTimes <= 0) {
                        httpURLConnection = createUrlConnection(url2);
                        settingHeaders(downloadTask, httpURLConnection);
                        try {
                            httpURLConnection.connect();
                        } catch (IOException e) {
                            throw e;
                        }
                    } else {
                        httpURLConnection = createUrlConnection(url2);
                        settingHeaders(downloadTask, httpURLConnection);
                        rangeHeaders(downloadTask, httpURLConnection);
                        try {
                            httpURLConnection.connect();
                        } catch (IOException e2) {
                            throw e2;
                        }
                    }
                    if (downloadTask.isPausing()) {
                        downloadTask.pause();
                        if (httpURLConnection != null) {
                            httpURLConnection.disconnect();
                        }
                        return ERROR_USER_PAUSE;
                    } else if (downloadTask.isPaused()) {
                        if (httpURLConnection != null) {
                            httpURLConnection.disconnect();
                        }
                        return ERROR_USER_PAUSE;
                    } else if (!downloadTask.isCanceled()) {
                        try {
                            z = "chunked".equalsIgnoreCase(httpURLConnection.getHeaderField("Transfer-Encoding"));
                        } catch (Throwable th) {
                            th.printStackTrace();
                            z = false;
                        }
                        headerFieldLong = getHeaderFieldLong(httpURLConnection, "Content-Length");
                        boolean z2 = headerFieldLong > 0;
                        boolean z3 = (z && z2) || (!z && !z2);
                        int responseCode = httpURLConnection.getResponseCode();
                        Runtime instance = Runtime.getInstance();
                        String str3 = TAG;
                        instance.log(str3, "responseCode:" + responseCode);
                        this.mDownloadMessage.append("responseCode=").append(responseCode).append("\n");
                        if (responseCode != 206 || z2) {
                            if (responseCode == 200) {
                                str = str2;
                                if (z3) {
                                    Runtime.getInstance().logError(str3, " error , giving up ,  EncodingChunked:" + z + "  hasLength:" + z2 + " response length:" + headerFieldLong + " responseCode:" + responseCode);
                                    downloadTask.error();
                                    if (httpURLConnection != null) {
                                        httpURLConnection.disconnect();
                                    }
                                    return ERROR_LOAD;
                                }
                                this.mTotals = headerFieldLong;
                                if (downloadTask.connectTimes <= 0) {
                                    start(httpURLConnection);
                                    downloadTask.connectTimes++;
                                    if (downloadTask.getFile().length() > 0 && !z) {
                                        if (downloadTask.getFile().length() == headerFieldLong) {
                                            this.mDownloadMessage.append("file already exist, file name=").append(downloadTask.getFile().getName()).append(", file length==contentLength").append(",contentLength=").append(headerFieldLong).append("\n");
                                            String md5 = Runtime.getInstance().md5(downloadTask.getFile());
                                            int compare = Runtime.getInstance().getFileComparator().compare(downloadTask.getUrl(), downloadTask.getFile(), downloadTask.getTargetCompareMD5(), md5);
                                            this.mDownloadMessage.append("compareResult=").append(compare).append("\n");
                                            this.mDownloadMessage.append("compare Result table:").append("COMPARE_RESULT_SUCCESSFUL = 1").append(",COMPARE_RESULT_REDOWNLOAD_COVER = 2").append(",COMPARE_RESULT_REDOWNLOAD_RENAME = 3").append("\n");
                                            if (compare == 1) {
                                                downloadTask.setFileMD5(md5);
                                                this.mLastLoaded = headerFieldLong;
                                                publishProgressUpdate(1);
                                                downloadTask.successful();
                                                if (httpURLConnection == null) {
                                                    return 8192;
                                                }
                                                httpURLConnection.disconnect();
                                                return 8192;
                                            } else if (compare == 2) {
                                                downloadTask.getFile().delete();
                                                downloadTask.getFile().createNewFile();
                                            } else {
                                                int i3 = 1;
                                                while (true) {
                                                    if (i3 < Integer.MAX_VALUE) {
                                                        File file = new File(downloadTask.getFile().getParent(), "(" + i3 + ")" + downloadTask.getFile().getName());
                                                        if (!file.exists()) {
                                                            this.mDownloadMessage.append("target file is not exist, create new target file ,file name=").append(file.getName()).append("\n");
                                                            file.createNewFile();
                                                            downloadTask.setFileSafe(file);
                                                        } else if (file.length() >= headerFieldLong) {
                                                            Runtime.getInstance().log(TAG, "rename download , targetFile exists:" + file.getName());
                                                            i3++;
                                                        } else {
                                                            this.mDownloadMessage.append("origin file name=").append(downloadTask.getFile().getName()).append(" target file name=").append(file.getName()).append(",current target file length=").append(file.length()).append("\n");
                                                            downloadTask.setFileSafe(file);
                                                        }
                                                    }
                                                }
                                            }
                                        } else if (downloadTask.getFile().length() >= headerFieldLong) {
                                            this.mDownloadMessage.append("file length error .").append("\n");
                                            downloadTask.getFile().delete();
                                            downloadTask.getFile().createNewFile();
                                        }
                                    }
                                }
                            } else if (responseCode != 206) {
                                if (responseCode != 307) {
                                    if (responseCode != 404) {
                                        if (responseCode != 4016) {
                                            switch (responseCode) {
                                                case 301:
                                                case 302:
                                                case 303:
                                                    break;
                                                default:
                                                    switch (responseCode) {
                                                        case 500:
                                                        case TypedValues.PositionType.TYPE_TRANSITION_EASING:
                                                        case TypedValues.PositionType.TYPE_DRAWPATH:
                                                        case TypedValues.PositionType.TYPE_PERCENT_WIDTH:
                                                            downloadTask.error();
                                                            if (httpURLConnection != null) {
                                                                httpURLConnection.disconnect();
                                                            }
                                                            return ERROR_SERVICE;
                                                        default:
                                                            downloadTask.error();
                                                            if (httpURLConnection == null) {
                                                                return ERROR_RESPONSE_STATUS;
                                                            }
                                                            httpURLConnection.disconnect();
                                                            return ERROR_RESPONSE_STATUS;
                                                    }
                                            }
                                        } else {
                                            if (downloadTask.getFile() != null) {
                                                Runtime.getInstance().log(str3, str2);
                                                this.mDownloadMessage.append(str2).append("\n");
                                                downloadTask.getFile().delete();
                                                downloadTask.getFile().createNewFile();
                                            }
                                            str = str2;
                                        }
                                    } else if (httpURLConnection == null) {
                                        return ERROR_RESOURCE_NOT_FOUND;
                                    } else {
                                        httpURLConnection.disconnect();
                                        return ERROR_RESOURCE_NOT_FOUND;
                                    }
                                }
                                String headerField = httpURLConnection.getHeaderField(AgentWebPermissions.ACTION_LOCATION);
                                if (TextUtils.isEmpty(headerField)) {
                                    downloadTask.error();
                                    if (httpURLConnection != null) {
                                        httpURLConnection.disconnect();
                                    }
                                    return ERROR_SERVICE;
                                }
                                this.mDownloadMessage.append("original url=").append(httpURLConnection.getURL().toString()).append("  ,redirect url=" + headerField).append("\n");
                                try {
                                    URL url3 = new URL(url2, headerField);
                                    downloadTask.setRedirect(url3.toString());
                                    url2 = url3;
                                    i = i2;
                                } catch (MalformedURLException unused) {
                                    downloadTask.error();
                                    if (httpURLConnection != null) {
                                        httpURLConnection.disconnect();
                                    }
                                    return ERROR_SERVICE;
                                }
                            } else if (z3) {
                                Runtime.getInstance().logError(str3, " error , giving up ,  EncodingChunked:" + z + "  hasLength:" + z2 + " response length:" + headerFieldLong + " responseCode:" + responseCode);
                                downloadTask.error();
                                if (httpURLConnection != null) {
                                    httpURLConnection.disconnect();
                                }
                                return ERROR_LOAD;
                            } else {
                                if (this.mTotals <= 0) {
                                    this.mTotals = downloadTask.getFile().length() + headerFieldLong;
                                }
                                if (this.mTotals <= 0 || downloadTask.getFile().length() + headerFieldLong == this.mTotals) {
                                    downloadTask.setTotalsLength(this.mTotals);
                                    if (!checkSpace()) {
                                        downloadTask.error();
                                        if (httpURLConnection != null) {
                                            httpURLConnection.disconnect();
                                        }
                                        return 16386;
                                    }
                                    Runtime.getInstance().log(str3, "last:" + this.mLastLoaded + " totals:" + this.mTotals);
                                    this.mDownloadMessage.append("last=").append(this.mLastLoaded).append(" totals=").append(this.mTotals).append("\n");
                                    int transferData = transferData(getInputStream(httpURLConnection), new LoadingRandomAccessFile(downloadTask.getFile()), true);
                                    if (httpURLConnection != null) {
                                        httpURLConnection.disconnect();
                                    }
                                    return transferData;
                                }
                                downloadTask.error();
                                Runtime.getInstance().logError(str3, "length error, this.mTotals:" + this.mTotals + " contentLength:" + headerFieldLong + " file length:" + downloadTask.getFile().length());
                                if (httpURLConnection != null) {
                                    httpURLConnection.disconnect();
                                }
                                return ERROR_LOAD;
                            }
                            i = i2;
                            str2 = str;
                        } else {
                            downloadTask.successful();
                            if (httpURLConnection != null) {
                                httpURLConnection.disconnect();
                            }
                            return 8192;
                        }
                    } else if (httpURLConnection == null) {
                        return ERROR_USER_CANCEL;
                    } else {
                        httpURLConnection.disconnect();
                        return ERROR_USER_CANCEL;
                    }
                } finally {
                    if (httpURLConnection != null) {
                        httpURLConnection.disconnect();
                    }
                }
            } else {
                downloadTask.error();
                if (httpURLConnection == null) {
                    return ERROR_TOO_MANY_REDIRECTS;
                }
                httpURLConnection.disconnect();
                return ERROR_TOO_MANY_REDIRECTS;
            }
        }
        if (z) {
            this.mTotals = -1;
        } else if (downloadTask.getFile().length() >= headerFieldLong) {
            this.mTotals = headerFieldLong;
            downloadTask.successful();
            if (httpURLConnection == null) {
                return 8192;
            }
            httpURLConnection.disconnect();
            return 8192;
        }
        downloadTask.setTotalsLength(this.mTotals);
        if (z || checkSpace()) {
            saveEtag(httpURLConnection);
            downloadTask.setTotalsLength(this.mTotals);
            this.mDownloadMessage.append("totals=").append(this.mTotals).append("\n");
            int transferData2 = transferData(getInputStream(httpURLConnection), new LoadingRandomAccessFile(downloadTask.getFile()), false);
            if (httpURLConnection != null) {
                httpURLConnection.disconnect();
            }
            return transferData2;
        }
        downloadTask.error();
        if (httpURLConnection != null) {
            httpURLConnection.disconnect();
        }
        return 16386;
    }

    private void rangeHeaders(DownloadTask downloadTask, HttpURLConnection httpURLConnection) {
        if (downloadTask.getFile() != null && downloadTask.getFile().length() > 0) {
            StringBuilder sb = new StringBuilder("bytes=");
            long length = downloadTask.getFile().length();
            this.mLastLoaded = length;
            sb.append(length);
            sb.append("-");
            httpURLConnection.setRequestProperty("Range", sb.toString());
        }
        this.mDownloadMessage.append("range=").append(this.mLastLoaded).append("\n");
        httpURLConnection.setRequestProperty("Connection", "close");
    }

    private final void start(HttpURLConnection httpURLConnection) throws IOException {
        DownloadTask downloadTask = this.mDownloadTask;
        if (TextUtils.isEmpty(downloadTask.getContentDisposition())) {
            downloadTask.setContentDisposition(httpURLConnection.getHeaderField("Content-Disposition"));
            String fileNameByContentDisposition = Runtime.getInstance().getFileNameByContentDisposition(downloadTask.getContentDisposition());
            if (!TextUtils.isEmpty(fileNameByContentDisposition) && !downloadTask.getFile().getName().equals(fileNameByContentDisposition)) {
                File file = new File(downloadTask.getFile().getParent(), fileNameByContentDisposition);
                if (file.exists()) {
                    downloadTask.setFileSafe(file);
                    updateNotifierTitle();
                } else {
                    File file2 = downloadTask.getFile();
                    if (downloadTask.getFile().renameTo(file)) {
                        downloadTask.setFileSafe(file);
                        updateNotifierTitle();
                        this.mDownloadMessage.append("origin=").append(file2.getName()).append(" rename=").append(file.getName()).append("\n");
                        file2.delete();
                    }
                }
            }
        }
        if (TextUtils.isEmpty(downloadTask.getMimetype())) {
            downloadTask.setMimetype(httpURLConnection.getHeaderField("Content-Type"));
        }
        if (TextUtils.isEmpty(downloadTask.getUserAgent())) {
            String headerField = httpURLConnection.getHeaderField("User-Agent");
            if (headerField == null) {
                headerField = BuildConfig.FLAVOR;
            }
            downloadTask.setUserAgent(headerField);
        }
        downloadTask.setContentLength(getHeaderFieldLong(httpURLConnection, "Content-Length"));
        onStart();
    }

    private void updateNotifierTitle() {
        DownloadTask downloadTask = this.mDownloadTask;
        DownloadNotifier downloadNotifier = downloadTask.mDownloadNotifier;
        if (downloadNotifier != null) {
            downloadNotifier.updateTitle(downloadTask);
        }
    }

    /* access modifiers changed from: protected */
    public void onStart() throws IOException {
        final DownloadTask downloadTask = this.mDownloadTask;
        if (downloadTask != null && downloadTask.getDownloadListener() != null) {
            HANDLER.post(new Runnable() {
                /* class com.download.library.Downloader.AnonymousClass1 */

                public void run() {
                    downloadTask.getDownloadListener().onStart(downloadTask.mUrl, downloadTask.mUserAgent, downloadTask.mContentDisposition, downloadTask.mMimetype, downloadTask.mTotalsLength, downloadTask);
                }
            });
        }
    }

    private InputStream getInputStream(HttpURLConnection httpURLConnection) throws IOException {
        if ("gzip".equalsIgnoreCase(httpURLConnection.getContentEncoding())) {
            return new GZIPInputStream(httpURLConnection.getInputStream());
        }
        if ("deflate".equalsIgnoreCase(httpURLConnection.getContentEncoding())) {
            return new InflaterInputStream(httpURLConnection.getInputStream(), new Inflater(true));
        }
        return httpURLConnection.getInputStream();
    }

    private long getHeaderFieldLong(HttpURLConnection httpURLConnection, String str) {
        String headerField = httpURLConnection.getHeaderField(str);
        if (headerField == null) {
            return -1;
        }
        try {
            return Long.parseLong(headerField);
        } catch (NumberFormatException e) {
            if (Runtime.getInstance().isDebug()) {
                e.printStackTrace();
            }
            return -1;
        }
    }

    private void saveEtag(HttpURLConnection httpURLConnection) {
        String headerField = httpURLConnection.getHeaderField("ETag");
        if (!TextUtils.isEmpty(headerField)) {
            String md5 = Runtime.getInstance().md5(this.mDownloadTask.getUrl());
            Runtime instance = Runtime.getInstance();
            String str = TAG;
            instance.log(str, "save etag:" + headerField);
            Runtime.getInstance().getStorageEngine(this.mDownloadTask.mContext).save(md5, headerField);
        }
    }

    private String getEtag() {
        String str = Runtime.getInstance().getStorageEngine(this.mDownloadTask.mContext).get(Runtime.getInstance().md5(this.mDownloadTask.getUrl()), "-1");
        if (TextUtils.isEmpty(str) || "-1".equals(str)) {
            return null;
        }
        return str;
    }

    private HttpURLConnection createUrlConnection(URL url) throws IOException {
        DownloadTask downloadTask = this.mDownloadTask;
        HttpURLConnection httpURLConnection = (HttpURLConnection) url.openConnection();
        httpURLConnection.setConnectTimeout((int) this.mConnectTimeOut);
        httpURLConnection.setInstanceFollowRedirects(false);
        httpURLConnection.setReadTimeout((int) downloadTask.getBlockMaxTime());
        httpURLConnection.setRequestProperty("Accept", "*/*");
        httpURLConnection.setRequestProperty("Accept-Encoding", "deflate,gzip");
        return httpURLConnection;
    }

    private void settingHeaders(DownloadTask downloadTask, HttpURLConnection httpURLConnection) {
        Map<String, String> headers = downloadTask.getHeaders();
        if (headers != null && !headers.isEmpty()) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                if (!TextUtils.isEmpty(entry.getKey()) && !TextUtils.isEmpty(entry.getValue())) {
                    httpURLConnection.setRequestProperty(entry.getKey(), entry.getValue());
                }
            }
        }
        String etag = getEtag();
        if (!TextUtils.isEmpty(etag)) {
            Runtime instance = Runtime.getInstance();
            String str = TAG;
            instance.log(str, "Etag:" + etag);
            httpURLConnection.setRequestProperty("If-Match", getEtag());
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.download.library.AsyncTask
    public void onProgressUpdate(Integer... numArr) {
        DownloadTask downloadTask = this.mDownloadTask;
        DownloadNotifier downloadNotifier = downloadTask.mDownloadNotifier;
        try {
            long elapsedRealtime = SystemClock.elapsedRealtime() - this.mBeginTime;
            this.mUsedTime = elapsedRealtime;
            if (elapsedRealtime == 0) {
                this.mAverageSpeed = 0;
            } else {
                this.mAverageSpeed = (this.mLoaded * 1000) / this.mUsedTime;
            }
            if (numArr != null && numArr.length > 0 && numArr[0].intValue() == 1 && downloadNotifier != null) {
                if (this.mTotals > 0) {
                    downloadNotifier.onDownloading((int) ((((float) (this.mLastLoaded + this.mLoaded)) / Float.valueOf((float) this.mTotals).floatValue()) * 100.0f));
                } else {
                    downloadNotifier.onDownloaded(this.mLastLoaded + this.mLoaded);
                }
            }
            if (downloadTask.getDownloadListener() != null) {
                downloadTask.getDownloadingListener().onProgress(downloadTask.getUrl(), this.mLastLoaded + this.mLoaded, this.mTotals, downloadTask.getUsedTime());
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private int transferData(InputStream inputStream, RandomAccessFile randomAccessFile, boolean z) throws IOException {
        byte[] bArr = new byte[8192];
        BufferedInputStream bufferedInputStream = new BufferedInputStream(inputStream, 8192);
        DownloadTask downloadTask = this.mDownloadTask;
        this.mLoaded = 0;
        if (z) {
            try {
                randomAccessFile.seek(randomAccessFile.length());
            } catch (Throwable th) {
                closeIO(randomAccessFile);
                closeIO(bufferedInputStream);
                closeIO(inputStream);
                throw th;
            }
        } else {
            randomAccessFile.seek(0);
            this.mLastLoaded = 0;
        }
        while (!downloadTask.isPausing() && !downloadTask.isCanceled() && !downloadTask.isPaused()) {
            try {
                int read = bufferedInputStream.read(bArr, 0, 8192);
                if (read == -1) {
                    break;
                }
                randomAccessFile.write(bArr, 0, read);
                if (SystemClock.elapsedRealtime() - this.mBeginTime > this.mDownloadTimeOut) {
                    this.mDownloadTask.error();
                    closeIO(randomAccessFile);
                    closeIO(bufferedInputStream);
                    closeIO(inputStream);
                    return ERROR_TIME_OUT;
                }
            } catch (IOException e) {
                downloadTask.error();
                throw e;
            }
        }
        if (downloadTask.isPausing()) {
            downloadTask.pause();
        } else if (!downloadTask.isPaused()) {
            if (downloadTask.isCanceled()) {
                closeIO(randomAccessFile);
                closeIO(bufferedInputStream);
                closeIO(inputStream);
                return ERROR_USER_CANCEL;
            }
            if (downloadTask.isCalculateMD5()) {
                this.mDownloadTask.setFileMD5(Runtime.getInstance().md5(this.mDownloadTask.mFile));
            }
            if (!TextUtils.isEmpty(downloadTask.getTargetCompareMD5())) {
                if (TextUtils.isEmpty(downloadTask.fileMD5)) {
                    this.mDownloadTask.setFileMD5(Runtime.getInstance().md5(this.mDownloadTask.mFile));
                }
                if (!downloadTask.getTargetCompareMD5().equalsIgnoreCase(downloadTask.getFileMD5())) {
                    downloadTask.error();
                    closeIO(randomAccessFile);
                    closeIO(bufferedInputStream);
                    closeIO(inputStream);
                    return ERROR_MD5;
                }
            }
            progressFinaly();
            downloadTask.successful();
            closeIO(randomAccessFile);
            closeIO(bufferedInputStream);
            closeIO(inputStream);
            return 8192;
        }
        closeIO(randomAccessFile);
        closeIO(bufferedInputStream);
        closeIO(inputStream);
        return ERROR_USER_PAUSE;
    }

    public void closeIO(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @Override // com.download.library.IDownloader
    public final DownloadTask cancel() {
        DownloadTask downloadTask = this.mDownloadTask;
        downloadTask.cancel();
        return downloadTask;
    }

    @Override // com.download.library.IDownloader
    public int status() {
        DownloadTask downloadTask = this.mDownloadTask;
        if (downloadTask == null) {
            return 1000;
        }
        return downloadTask.getStatus();
    }

    private final DownloadTask pause() {
        DownloadTask downloadTask = this.mDownloadTask;
        downloadTask.pausing();
        return downloadTask;
    }

    @Override // com.download.library.ExecuteTask
    public DownloadTask cancelDownload() {
        return cancel();
    }

    @Override // com.download.library.ExecuteTask
    public DownloadTask pauseDownload() {
        return pause();
    }

    @Override // com.download.library.ExecuteTask
    public DownloadTask getDownloadTask() {
        return this.mDownloadTask;
    }

    /* access modifiers changed from: private */
    public final class LoadingRandomAccessFile extends RandomAccessFile {
        public LoadingRandomAccessFile(File file) throws FileNotFoundException {
            super(file, "rw");
        }

        @Override // java.io.RandomAccessFile, java.io.DataOutput
        public void write(byte[] bArr, int i, int i2) throws IOException {
            super.write(bArr, i, i2);
            Downloader.access$014(Downloader.this, (long) i2);
            DownloadTask downloadTask = Downloader.this.mDownloadTask;
            if (downloadTask != null) {
                downloadTask.setLoaded(Downloader.this.mLastLoaded + Downloader.this.mLoaded);
            }
            Downloader.this.onProgress();
        }
    }

    private void progressFinaly() {
        this.mLastTime = SystemClock.elapsedRealtime();
        publishProgressUpdate(1);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onProgress() {
        if (this.enableProgress) {
            if (this.quickProgress) {
                long elapsedRealtime = SystemClock.elapsedRealtime();
                if (elapsedRealtime - this.mLastTime < 1200) {
                    publishProgressUpdate(0);
                    return;
                }
                this.mLastTime = elapsedRealtime;
                publishProgressUpdate(1);
                return;
            }
            long elapsedRealtime2 = SystemClock.elapsedRealtime();
            if (elapsedRealtime2 - this.mLastTime >= 1200) {
                this.mLastTime = elapsedRealtime2;
                publishProgressUpdate(1);
            }
        }
    }

    private void publishProgressUpdate(int i) {
        if (this.mCallbackInMainThread) {
            publishProgress(Integer.valueOf(i));
            return;
        }
        onProgressUpdate(Integer.valueOf(i));
    }
}
