package com.download.library;

import android.text.TextUtils;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

public final class ExecuteTasksMap {
    private ConcurrentHashMap<String, ExecuteTask> mTasks;

    private ExecuteTasksMap() {
        this.mTasks = new ConcurrentHashMap<>();
    }

    static ExecuteTasksMap getInstance() {
        return ExecuteTaskHolder.INSTANCE;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask cancelTask(String str) {
        ExecuteTask executeTask = this.mTasks.get(str);
        if (executeTask != null) {
            return executeTask.cancelDownload();
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    public DownloadTask pauseTask(String str) {
        DownloadTask downloadTask;
        ExecuteTask executeTask = this.mTasks.get(str);
        if (executeTask == null || (downloadTask = executeTask.getDownloadTask()) == null || downloadTask.getStatus() != 1002) {
            return null;
        }
        return executeTask.pauseDownload();
    }

    /* access modifiers changed from: package-private */
    public List<DownloadTask> cancelTasks() {
        Set<Map.Entry<String, ExecuteTask>> entrySet = this.mTasks.entrySet();
        if (entrySet.size() <= 0) {
            return null;
        }
        ArrayList arrayList = new ArrayList(entrySet.size());
        for (Map.Entry<String, ExecuteTask> entry : entrySet) {
            DownloadTask cancelDownload = entry.getValue().cancelDownload();
            if (cancelDownload != null) {
                arrayList.add(cancelDownload);
            }
        }
        return arrayList;
    }

    /* access modifiers changed from: package-private */
    public List<DownloadTask> pauseTasks() {
        Set<Map.Entry<String, ExecuteTask>> entrySet = this.mTasks.entrySet();
        if (entrySet.size() <= 0) {
            return null;
        }
        ArrayList arrayList = new ArrayList(entrySet.size());
        for (Map.Entry<String, ExecuteTask> entry : entrySet) {
            DownloadTask pauseDownload = entry.getValue().pauseDownload();
            if (pauseDownload != null) {
                arrayList.add(pauseDownload);
            }
        }
        return arrayList;
    }

    /* access modifiers changed from: package-private */
    public void addTask(String str, ExecuteTask executeTask) {
        if (str != null && executeTask != null) {
            this.mTasks.put(str, executeTask);
        }
    }

    /* access modifiers changed from: package-private */
    public void removeTask(String str) {
        if (str != null) {
            this.mTasks.remove(str);
        }
    }

    /* access modifiers changed from: package-private */
    public boolean exist(String str) {
        return !TextUtils.isEmpty(str) && this.mTasks.get(str) != null;
    }

    private static class ExecuteTaskHolder {
        private static final ExecuteTasksMap INSTANCE = new ExecuteTasksMap();

        private ExecuteTaskHolder() {
        }
    }
}
