package com.download.library;

import android.os.AsyncTask;
import java.util.concurrent.Executor;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

public final class Executors {
    private static volatile Executor IO = null;
    protected static final Executor SERIAL_EXECUTOR = new SerialExecutor();
    private static final String TAG = "Executors";
    private static volatile Executor TASK_ENQUEUE_DISPATCH;
    private static volatile Executor TASK_QUEUEDUP_DISPATCH;

    public static Executor io() {
        if (IO != null) {
            return IO;
        }
        synchronized (Executors.class) {
            if (IO == null) {
                ThreadPoolExecutor threadPoolExecutor = new ThreadPoolExecutor(4, 4, 30, TimeUnit.MILLISECONDS, new LinkedBlockingQueue(), new ThreadFactory() {
                    /* class com.download.library.Executors.AnonymousClass1 */

                    public Thread newThread(Runnable runnable) {
                        return new Thread(runnable);
                    }
                });
                threadPoolExecutor.allowCoreThreadTimeOut(true);
                IO = threadPoolExecutor;
            }
        }
        return IO;
    }

    public static Executor getSerialExecutor() {
        return SERIAL_EXECUTOR;
    }

    public static Executor taskEnqueueDispatchExecutor() {
        if (TASK_ENQUEUE_DISPATCH != null) {
            return TASK_ENQUEUE_DISPATCH;
        }
        synchronized (Executors.class) {
            if (TASK_ENQUEUE_DISPATCH == null) {
                ThreadPoolExecutor threadPoolExecutor = new ThreadPoolExecutor(1, 1, 30, TimeUnit.MILLISECONDS, new LinkedBlockingQueue(), new ThreadFactory() {
                    /* class com.download.library.Executors.AnonymousClass2 */

                    public Thread newThread(Runnable runnable) {
                        return new Thread(runnable);
                    }
                });
                threadPoolExecutor.allowCoreThreadTimeOut(true);
                TASK_ENQUEUE_DISPATCH = threadPoolExecutor;
            }
        }
        return TASK_ENQUEUE_DISPATCH;
    }

    public static Executor taskQueuedUpDispatchExecutor() {
        if (TASK_QUEUEDUP_DISPATCH != null) {
            return TASK_QUEUEDUP_DISPATCH;
        }
        synchronized (Executors.class) {
            if (TASK_QUEUEDUP_DISPATCH == null) {
                ThreadPoolExecutor threadPoolExecutor = new ThreadPoolExecutor(1, 1, 30, TimeUnit.MILLISECONDS, new LinkedBlockingQueue(), new ThreadFactory() {
                    /* class com.download.library.Executors.AnonymousClass3 */

                    public Thread newThread(Runnable runnable) {
                        return new Thread(runnable);
                    }
                });
                threadPoolExecutor.allowCoreThreadTimeOut(true);
                TASK_QUEUEDUP_DISPATCH = threadPoolExecutor;
            }
        }
        return TASK_QUEUEDUP_DISPATCH;
    }

    public static void setTaskEnqueueDispatchExecutor(Executor executor) {
        if (executor == null) {
            Runtime.getInstance().logError(TAG, "executor is null");
            return;
        }
        synchronized (Executors.class) {
            Executor executor2 = TASK_ENQUEUE_DISPATCH;
            try {
                TASK_ENQUEUE_DISPATCH = executor;
            } finally {
                if (executor2 != null && (executor2 instanceof ExecutorService)) {
                    ((ExecutorService) executor2).shutdown();
                }
            }
        }
    }

    public static void setTaskQueuedupDispatchExecutor(Executor executor) {
        if (executor == null) {
            Runtime.getInstance().logError(TAG, "executor is null");
            return;
        }
        synchronized (Executors.class) {
            Executor executor2 = TASK_QUEUEDUP_DISPATCH;
            try {
                TASK_QUEUEDUP_DISPATCH = executor;
            } finally {
                if (executor2 != null && (executor2 instanceof ExecutorService)) {
                    ((ExecutorService) executor2).shutdown();
                }
            }
        }
    }

    public static void setIO(Executor executor) {
        if (executor == null) {
            Runtime.getInstance().logError(TAG, "executor is null");
            return;
        }
        synchronized (Executors.class) {
            Executor executor2 = IO;
            try {
                IO = executor;
            } finally {
                if (!(executor2 == null || executor2 == AsyncTask.THREAD_POOL_EXECUTOR || !(executor2 instanceof ExecutorService))) {
                    ((ExecutorService) executor2).shutdown();
                }
            }
        }
    }
}
