package com.download.library;

import android.app.ActivityManager;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.Build;
import android.os.Process;
import android.text.TextUtils;
import android.util.Log;
import android.webkit.MimeTypeMap;
import androidx.core.content.FileProvider;
import com.download.library.DefaultFileComparator;
import com.download.library.DefaultStorageEngine;
import com.download.library.FileComparator;
import com.download.library.StorageEngine;
import com.queue.library.BuildConfig;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Field;
import java.math.BigInteger;
import java.net.URLDecoder;
import java.security.MessageDigest;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public final class Runtime {
    private static final Pattern CONTENT_DISPOSITION_WITHOUT_ASTERISK_PATTERN = Pattern.compile("attachment;\\s*filename\\s*=\\s*\"*([^\"\\n]*)\"*");
    private static Pattern DISPOSITION_PATTERN = Pattern.compile("attachment;\\s*filename\\*\\s*=\\s*\"*([^\"]*)'\\S*'([^\"]*)\"*");
    static final String PREFIX = "Download-";
    private static final String TAG = "Runtime";
    private static final Runtime sInstance = new Runtime();
    boolean DEBUG = false;
    private String authority;
    private File mDownloadDir = null;
    private FileComparator mFileComparator;
    private FileComparator.FileComparatorFactory mFileComparatorFactory;
    private AtomicInteger mIDGenerator = new AtomicInteger(1);
    private StorageEngine mStorageEngine;
    private StorageEngine.StorageEngineFactory mStorageEngineFactory;
    private AtomicInteger mThreadGlobalCounter = new AtomicInteger(1);
    private DownloadTask sDefaultDownloadTask;

    public void setDebug(boolean z) {
        this.DEBUG = z;
    }

    public boolean isDebug() {
        return this.DEBUG;
    }

    private Runtime() {
    }

    public static Runtime getInstance() {
        return sInstance;
    }

    public StorageEngine getStorageEngine(Context context) {
        StorageEngine storageEngine = this.mStorageEngine;
        if (storageEngine != null) {
            return storageEngine;
        }
        StorageEngine newStorageEngine = getStorageEngineFactory().newStorageEngine(context);
        this.mStorageEngine = newStorageEngine;
        return newStorageEngine;
    }

    /* access modifiers changed from: package-private */
    public StorageEngine.StorageEngineFactory getStorageEngineFactory() {
        StorageEngine.StorageEngineFactory storageEngineFactory = this.mStorageEngineFactory;
        if (storageEngineFactory != null) {
            return storageEngineFactory;
        }
        DefaultStorageEngine.DefaultStorageEngineFactory defaultStorageEngineFactory = new DefaultStorageEngine.DefaultStorageEngineFactory();
        this.mStorageEngineFactory = defaultStorageEngineFactory;
        return defaultStorageEngineFactory;
    }

    public FileComparator getFileComparator() {
        FileComparator fileComparator = this.mFileComparator;
        if (fileComparator != null) {
            return fileComparator;
        }
        FileComparator newFileComparator = getFileComparatorFactory().newFileComparator();
        this.mFileComparator = newFileComparator;
        return newFileComparator;
    }

    /* access modifiers changed from: package-private */
    public FileComparator.FileComparatorFactory getFileComparatorFactory() {
        FileComparator.FileComparatorFactory fileComparatorFactory = this.mFileComparatorFactory;
        return fileComparatorFactory == null ? new DefaultFileComparator.DefaultFileComparatorFactory() : fileComparatorFactory;
    }

    public void setFileComparatorFactory(FileComparator.FileComparatorFactory fileComparatorFactory) {
        this.mFileComparatorFactory = fileComparatorFactory;
        this.mFileComparator = null;
    }

    public void setStorageEngineFactory(StorageEngine.StorageEngineFactory storageEngineFactory) {
        this.mStorageEngineFactory = storageEngineFactory;
        this.mStorageEngine = null;
    }

    public synchronized DownloadTask getDefaultDownloadTask() {
        if (this.sDefaultDownloadTask == null) {
            createDefaultDownloadTask();
        }
        return this.sDefaultDownloadTask.clone();
    }

    private synchronized void createDefaultDownloadTask() {
        DownloadTask downloadTask = new DownloadTask();
        this.sDefaultDownloadTask = downloadTask;
        downloadTask.setBreakPointDownload(true).setIcon(17301633).setConnectTimeOut(6000).setBlockMaxTime(600000).setDownloadTimeOut(Long.MAX_VALUE).setParallelDownload(true).setEnableIndicator(false).closeAutoOpen().setForceDownload(true);
    }

    public synchronized void setDownloadTask(DownloadTask downloadTask) {
        this.sDefaultDownloadTask = downloadTask;
    }

    public String getIdentify(Context context) {
        return append(context, "Downloader");
    }

    public int generateGlobalId() {
        return this.mIDGenerator.getAndIncrement();
    }

    public int generateGlobalThreadId() {
        return this.mThreadGlobalCounter.getAndIncrement();
    }

    public File createFile(Context context, DownloadTask downloadTask) {
        return createFile(context, downloadTask, null);
    }

    /* JADX WARNING: Removed duplicated region for block: B:40:0x00b7 A[Catch:{ all -> 0x00ed }] */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00e6 A[Catch:{ all -> 0x00ed }] */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x00e7 A[Catch:{ all -> 0x00ed }] */
    public File createFile(Context context, DownloadTask downloadTask, File file) {
        String str;
        File file2;
        boolean z;
        Uri parse;
        try {
            String fileNameByContentDisposition = getFileNameByContentDisposition(downloadTask.getContentDisposition());
            boolean z2 = true;
            if (TextUtils.isEmpty(fileNameByContentDisposition) && !TextUtils.isEmpty(downloadTask.getUrl()) && (parse = Uri.parse(downloadTask.getUrl())) != null && !TextUtils.isEmpty(parse.getPath()) && parse.getPath().contains("/")) {
                fileNameByContentDisposition = parse.getPath().substring(parse.getPath().lastIndexOf(47) + 1);
            }
            if (!TextUtils.isEmpty(fileNameByContentDisposition) && fileNameByContentDisposition.length() > 64) {
                fileNameByContentDisposition = fileNameByContentDisposition.substring(fileNameByContentDisposition.length() - 64, fileNameByContentDisposition.length());
            }
            if (TextUtils.isEmpty(fileNameByContentDisposition)) {
                fileNameByContentDisposition = md5(downloadTask.getUrl());
            }
            if (fileNameByContentDisposition.contains("\"")) {
                fileNameByContentDisposition = fileNameByContentDisposition.replace("\"", BuildConfig.FLAVOR);
            }
            if (file != null) {
                if (file.isDirectory()) {
                    str = file.getAbsolutePath();
                    file2 = new File(str);
                    if (!file2.exists()) {
                        file2.mkdirs();
                    }
                    if (downloadTask.isDataURI() && !fileNameByContentDisposition.contains(".")) {
                        fileNameByContentDisposition = fileNameByContentDisposition + "." + findExtensionFromUri(downloadTask.getUrl());
                    }
                    if (downloadTask.isBreakPointDownload()) {
                        z2 = false;
                    }
                    return createFileByName(file2, context, fileNameByContentDisposition, z2);
                }
            }
            if (!downloadTask.isEnableIndicator()) {
                if (!downloadTask.isAutoOpen()) {
                    z = false;
                    str = getDir(context, z).getPath();
                    file2 = new File(str);
                    if (!file2.exists()) {
                    }
                    fileNameByContentDisposition = fileNameByContentDisposition + "." + findExtensionFromUri(downloadTask.getUrl());
                    if (downloadTask.isBreakPointDownload()) {
                    }
                    return createFileByName(file2, context, fileNameByContentDisposition, z2);
                }
            }
            z = true;
            str = getDir(context, z).getPath();
            file2 = new File(str);
            if (!file2.exists()) {
            }
            fileNameByContentDisposition = fileNameByContentDisposition + "." + findExtensionFromUri(downloadTask.getUrl());
            if (downloadTask.isBreakPointDownload()) {
            }
            return createFileByName(file2, context, fileNameByContentDisposition, z2);
        } catch (Throwable th) {
            th.printStackTrace();
            return null;
        }
    }

    private String findExtensionFromUri(String str) {
        int i = -1;
        for (int i2 = 5; i2 < str.length(); i2++) {
            String valueOf = String.valueOf(str.charAt(i2));
            if (valueOf.equalsIgnoreCase(";")) {
                i = i2;
            } else if (valueOf.equalsIgnoreCase(",")) {
                break;
            }
        }
        if (i <= 5) {
            return BuildConfig.FLAVOR;
        }
        String substring = str.substring(5, i);
        String str2 = TAG;
        log(str2, "mimeType:" + substring);
        return MimeTypeMap.getSingleton().getExtensionFromMimeType(substring);
    }

    /* access modifiers changed from: package-private */
    public boolean checkWifi(Context context) {
        NetworkInfo activeNetworkInfo;
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager != null && (activeNetworkInfo = connectivityManager.getActiveNetworkInfo()) != null && activeNetworkInfo.isConnected() && activeNetworkInfo.getType() == 1) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public boolean checkNetwork(Context context) {
        NetworkInfo activeNetworkInfo;
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager == null || (activeNetworkInfo = connectivityManager.getActiveNetworkInfo()) == null || !activeNetworkInfo.isConnected()) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    public File createFileByName(File file, Context context, String str, boolean z) throws IOException {
        if (!file.isDirectory()) {
            return null;
        }
        File file2 = new File(file, str);
        if (!file2.exists()) {
            file2.createNewFile();
        } else if (z) {
            file2.delete();
            file2.createNewFile();
        }
        return file2;
    }

    /* access modifiers changed from: package-private */
    public String getFileNameByContentDisposition(String str) {
        if (TextUtils.isEmpty(str)) {
            return BuildConfig.FLAVOR;
        }
        try {
            Matcher matcher = DISPOSITION_PATTERN.matcher(str);
            if (matcher.find()) {
                return URLDecoder.decode(matcher.group(2), matcher.group(1));
            }
            Matcher matcher2 = CONTENT_DISPOSITION_WITHOUT_ASTERISK_PATTERN.matcher(str);
            if (matcher2.find()) {
                return matcher2.group(1);
            }
            return BuildConfig.FLAVOR;
        } catch (UnsupportedEncodingException | IllegalStateException unused) {
        }
    }

    /* access modifiers changed from: package-private */
    public File getDir(Context context, boolean z) {
        File file = this.mDownloadDir;
        File cacheDir = (file == null || !file.isDirectory()) ? context.getCacheDir() : this.mDownloadDir;
        StringBuilder sb = new StringBuilder("download");
        sb.append(File.separator);
        sb.append(z ? "public" : "private");
        File file2 = new File(cacheDir, sb.toString());
        if (!file2.exists()) {
            file2.mkdirs();
        }
        return file2;
    }

    public File getDir(Context context) {
        return getDir(context, false);
    }

    public File getDefaultDir(Context context) {
        File file = new File(context.getCacheDir(), "download");
        if (!file.exists()) {
            file.mkdirs();
        }
        return file;
    }

    public void log(String str, String str2) {
        if (this.DEBUG && !TextUtils.isEmpty(str2)) {
            Log.i(str, str2);
        }
    }

    public void log(String str, String str2, Throwable th) {
        if (this.DEBUG) {
            Log.i(str, str2, th);
        }
    }

    public File uniqueFile(DownloadTask downloadTask, File file) {
        String md5 = getInstance().md5(downloadTask.getUrl());
        if (file == null || !file.isDirectory()) {
            file = getInstance().getDir(downloadTask.getContext(), downloadTask.isEnableIndicator() || downloadTask.isAutoOpen());
        }
        File file2 = new File(file, md5);
        if (!file2.exists()) {
            file2.mkdirs();
        }
        if (!file2.isDirectory()) {
            file2.delete();
            file2.mkdirs();
        }
        return createFile(downloadTask.getContext(), downloadTask, file2);
    }

    public void setDownloadDir(File file, String str) {
        this.mDownloadDir = file;
        this.authority = str;
    }

    public void logError(String str, String str2) {
        if (this.DEBUG) {
            Log.e(str, str2);
        }
    }

    public String md5(String str) {
        try {
            MessageDigest instance = MessageDigest.getInstance("MD5");
            instance.update(str.getBytes());
            return new BigInteger(1, instance.digest()).toString(16);
        } catch (Exception e) {
            if (!isDebug()) {
                return BuildConfig.FLAVOR;
            }
            e.printStackTrace();
            return BuildConfig.FLAVOR;
        }
    }

    public String md5(File file) {
        byte[] bArr = new byte[1024];
        try {
            if (!file.isFile()) {
                return BuildConfig.FLAVOR;
            }
            MessageDigest instance = MessageDigest.getInstance("MD5");
            FileInputStream fileInputStream = new FileInputStream(file);
            while (true) {
                int read = fileInputStream.read(bArr, 0, 1024);
                if (read == -1) {
                    fileInputStream.close();
                    return String.format("%1$032x", new BigInteger(1, instance.digest()));
                }
                instance.update(bArr, 0, read);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public String getApplicationName(Context context) {
        PackageManager packageManager;
        ApplicationInfo applicationInfo = null;
        try {
            packageManager = context.getApplicationContext().getPackageManager();
            try {
                applicationInfo = packageManager.getApplicationInfo(context.getPackageName(), 0);
            } catch (PackageManager.NameNotFoundException unused) {
            }
        } catch (PackageManager.NameNotFoundException unused2) {
            packageManager = null;
        }
        return (String) packageManager.getApplicationLabel(applicationInfo);
    }

    public Intent getCommonFileIntentCompat(Context context, DownloadTask downloadTask) {
        Intent action = new Intent().setAction("android.intent.action.VIEW");
        setIntentDataAndType(context, action, getMimeType(downloadTask.getFile()), downloadTask.getFile(), false, downloadTask.isCustomFile() ? downloadTask.getAuthority() : getAuthority(downloadTask.getContext()));
        return action;
    }

    private String getAuthority(Context context) {
        if (!TextUtils.isEmpty(this.authority)) {
            return this.authority;
        }
        String str = context.getPackageName() + ".DownloadFileProvider";
        this.authority = str;
        return str;
    }

    public Uri getUriFromFile(Context context, File file, String str) {
        if (Build.VERSION.SDK_INT >= 24) {
            return FileProvider.getUriForFile(context, str, file);
        }
        return Uri.fromFile(file);
    }

    public Uri getUriFromFileForN(Context context, File file) {
        return FileProvider.getUriForFile(context, context.getPackageName() + ".DownloadFileProvider", file);
    }

    public void setIntentDataAndType(Context context, Intent intent, String str, File file, boolean z, String str2) {
        if (Build.VERSION.SDK_INT >= 24) {
            intent.setDataAndType(getUriFromFile(context, file, str2), str);
            intent.addFlags(1);
            if (z) {
                intent.addFlags(2);
                return;
            }
            return;
        }
        intent.setDataAndType(Uri.fromFile(file), str);
    }

    public String getMimeType(File file) {
        String name = file.getName();
        if (!name.contains(".")) {
            return "*/*";
        }
        String mimeTypeFromExtension = MimeTypeMap.getSingleton().getMimeTypeFromExtension(name.substring(name.lastIndexOf(".") + 1).toLowerCase());
        getInstance().log(TAG, mimeTypeFromExtension);
        if (TextUtils.isEmpty(mimeTypeFromExtension)) {
            return "*/*";
        }
        return mimeTypeFromExtension;
    }

    public String append(Context context, String str) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(getCurrentProcessName(context)).append("-").append(str);
        return stringBuffer.toString();
    }

    public String getCurrentProcessName(Context context) {
        String currentProcessNameByFile = getCurrentProcessNameByFile(context);
        if (!TextUtils.isEmpty(currentProcessNameByFile)) {
            return currentProcessNameByFile;
        }
        String currentProcessNameByAms = getCurrentProcessNameByAms(context);
        if (!TextUtils.isEmpty(currentProcessNameByAms)) {
            return currentProcessNameByAms;
        }
        return getCurrentProcessNameByReflect(context);
    }

    private static String getCurrentProcessNameByFile(Context context) {
        try {
            BufferedReader bufferedReader = new BufferedReader(new FileReader(new File("/proc/" + Process.myPid() + "/cmdline")));
            String trim = bufferedReader.readLine().trim();
            bufferedReader.close();
            return trim;
        } catch (Exception e) {
            e.printStackTrace();
            return BuildConfig.FLAVOR;
        }
    }

    private static String getCurrentProcessNameByAms(Context context) {
        List<ActivityManager.RunningAppProcessInfo> runningAppProcesses;
        try {
            ActivityManager activityManager = (ActivityManager) context.getSystemService("activity");
            if (!(activityManager == null || (runningAppProcesses = activityManager.getRunningAppProcesses()) == null)) {
                if (runningAppProcesses.size() != 0) {
                    int myPid = Process.myPid();
                    for (ActivityManager.RunningAppProcessInfo runningAppProcessInfo : runningAppProcesses) {
                        if (runningAppProcessInfo.pid == myPid && runningAppProcessInfo.processName != null) {
                            return runningAppProcessInfo.processName;
                        }
                    }
                }
            }
        } catch (Exception unused) {
        }
        return BuildConfig.FLAVOR;
    }

    private static String getCurrentProcessNameByReflect(Context context) {
        try {
            Application application = (Application) context.getApplicationContext();
            Field field = application.getClass().getField("mLoadedApk");
            field.setAccessible(true);
            Object obj = field.get(application);
            Field declaredField = obj.getClass().getDeclaredField("mActivityThread");
            declaredField.setAccessible(true);
            Object obj2 = declaredField.get(obj);
            return (String) obj2.getClass().getDeclaredMethod("getProcessName", new Class[0]).invoke(obj2, new Object[0]);
        } catch (Exception e) {
            e.printStackTrace();
            return BuildConfig.FLAVOR;
        }
    }
}
