package com.just.agentweb;

import android.app.Activity;
import android.content.Context;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.webkit.DownloadListener;
import android.webkit.WebView;
import com.download.library.DownloadImpl;
import com.download.library.DownloadListenerAdapter;
import com.download.library.Extra;
import com.download.library.ResourceRequest;
import com.just.agentweb.AgentActionFragment;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;

public class DefaultDownloadImpl implements DownloadListener {
    private static final String TAG = "DefaultDownloadImpl";
    private static Handler mHandler = new Handler(Looper.getMainLooper());
    private boolean isInstallDownloader;
    protected WeakReference<Activity> mActivityWeakReference = null;
    protected WeakReference<AbsAgentWebUIController> mAgentWebUIController;
    protected Context mContext;
    protected ConcurrentHashMap<String, ResourceRequest> mDownloadTasks = new ConcurrentHashMap<>();
    protected PermissionInterceptor mPermissionListener = null;

    protected DefaultDownloadImpl(Activity activity, WebView webView, PermissionInterceptor permissionInterceptor) {
        this.mContext = activity.getApplicationContext();
        this.mActivityWeakReference = new WeakReference<>(activity);
        this.mPermissionListener = permissionInterceptor;
        this.mAgentWebUIController = new WeakReference<>(AgentWebUtils.getAgentWebUIControllerByWebView(webView));
        try {
            DownloadImpl.getInstance(this.mContext);
            this.isInstallDownloader = true;
        } catch (Throwable th) {
            LogUtils.e(TAG, "implementation 'com.download.library:Downloader:x.x.x'");
            if (LogUtils.isDebug()) {
                th.printStackTrace();
            }
            this.isInstallDownloader = false;
        }
    }

    public static DefaultDownloadImpl create(Activity activity, WebView webView, PermissionInterceptor permissionInterceptor) {
        return new DefaultDownloadImpl(activity, webView, permissionInterceptor);
    }

    /* access modifiers changed from: protected */
    public List<String> checkNeedPermission() {
        ArrayList arrayList = new ArrayList();
        String[] strArr = AgentWebPermissions.STORAGE;
        if (!AgentWebUtils.hasPermission(this.mActivityWeakReference.get(), strArr)) {
            arrayList.addAll(Arrays.asList(strArr));
        }
        return arrayList;
    }

    /* access modifiers changed from: protected */
    public Handler.Callback createCallback(final String str) {
        return new Handler.Callback() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass3 */

            public boolean handleMessage(Message message) {
                DefaultDownloadImpl.this.forceDownload(str);
                return true;
            }
        };
    }

    /* access modifiers changed from: protected */
    public ResourceRequest createResourceRequest(String str) {
        return DownloadImpl.getInstance(this.mContext).with(str).setEnableIndicator(true).autoOpenIgnoreMD5();
    }

    /* access modifiers changed from: protected */
    public void forceDownload(String str) {
        this.mDownloadTasks.get(str).setForceDownload(true);
        performDownload(str);
    }

    /* access modifiers changed from: protected */
    public AgentActionFragment.PermissionListener getPermissionListener(final String str) {
        return new AgentActionFragment.PermissionListener() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass2 */

            @Override // com.just.agentweb.AgentActionFragment.PermissionListener
            public void onRequestPermissionsResult(String[] strArr, int[] iArr, Bundle bundle) {
                if (DefaultDownloadImpl.this.checkNeedPermission().isEmpty()) {
                    DefaultDownloadImpl.this.preDownload(str);
                    return;
                }
                if (DefaultDownloadImpl.this.mAgentWebUIController.get() != null) {
                    DefaultDownloadImpl.this.mAgentWebUIController.get().onPermissionsDeny((String[]) DefaultDownloadImpl.this.checkNeedPermission().toArray(new String[0]), AgentWebPermissions.ACTION_STORAGE, "Download");
                }
                LogUtils.e(DefaultDownloadImpl.TAG, "储存权限获取失败~");
            }
        };
    }

    /* access modifiers changed from: protected */
    public boolean isForceRequest(String str) {
        ResourceRequest resourceRequest = this.mDownloadTasks.get(str);
        if (resourceRequest != null) {
            return resourceRequest.getDownloadTask().isForceDownload();
        }
        return false;
    }

    public void onDownloadStart(final String str, final String str2, final String str3, final String str4, final long j) {
        if (!this.isInstallDownloader) {
            String str5 = TAG;
            LogUtils.e(str5, "unable start download " + str + "; implementation 'com.download.library:Downloader:x.x.x'");
            return;
        }
        mHandler.post(new Runnable() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass1 */

            public void run() {
                DefaultDownloadImpl.this.onDownloadStartInternal(str, str2, str3, str4, j);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void onDownloadStartInternal(String str, String str2, String str3, String str4, long j) {
        if (this.mActivityWeakReference.get() != null && !this.mActivityWeakReference.get().isFinishing()) {
            PermissionInterceptor permissionInterceptor = this.mPermissionListener;
            if (permissionInterceptor == null || !permissionInterceptor.intercept(str, AgentWebPermissions.STORAGE, "download")) {
                this.mDownloadTasks.put(str, createResourceRequest(str));
                if (Build.VERSION.SDK_INT >= 23) {
                    List<String> checkNeedPermission = checkNeedPermission();
                    if (!checkNeedPermission.isEmpty()) {
                        Action createPermissionsAction = Action.createPermissionsAction((String[]) checkNeedPermission.toArray(new String[0]));
                        createPermissionsAction.setPermissionListener(getPermissionListener(str));
                        AgentActionFragment.start(this.mActivityWeakReference.get(), createPermissionsAction);
                        return;
                    }
                }
                preDownload(str);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void performDownload(String str) {
        try {
            String str2 = TAG;
            LogUtils.e(str2, "performDownload:" + str + " exist:" + DownloadImpl.getInstance(this.mContext).exist(str));
            if (!DownloadImpl.getInstance(this.mContext).exist(str)) {
                ResourceRequest resourceRequest = this.mDownloadTasks.get(str);
                resourceRequest.addHeader("Cookie", AgentWebConfig.getCookiesByUrl(str));
                taskEnqueue(resourceRequest);
            } else if (this.mAgentWebUIController.get() != null) {
                this.mAgentWebUIController.get().onShowMessage(this.mActivityWeakReference.get().getString(R.string.agentweb_download_task_has_been_exist), "preDownload");
            }
        } catch (Throwable th) {
            if (LogUtils.isDebug()) {
                th.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void preDownload(String str) {
        if (isForceRequest(str) || AgentWebUtils.checkNetworkType(this.mContext) <= 1) {
            performDownload(str);
        } else {
            showDialog(str);
        }
    }

    /* access modifiers changed from: protected */
    public void showDialog(String str) {
        AbsAgentWebUIController absAgentWebUIController;
        Activity activity = this.mActivityWeakReference.get();
        if (activity != null && !activity.isFinishing() && (absAgentWebUIController = this.mAgentWebUIController.get()) != null) {
            absAgentWebUIController.onForceDownloadAlert(str, createCallback(str));
        }
    }

    /* access modifiers changed from: protected */
    public void taskEnqueue(ResourceRequest resourceRequest) {
        resourceRequest.enqueue((DownloadListenerAdapter) new DownloadListenerAdapter() {
            /* class com.just.agentweb.DefaultDownloadImpl.AnonymousClass4 */

            @Override // com.download.library.DownloadListener, com.download.library.DownloadListenerAdapter
            public boolean onResult(Throwable th, Uri uri, String str, Extra extra) {
                DefaultDownloadImpl.this.mDownloadTasks.remove(str);
                return super.onResult(th, uri, str, extra);
            }
        });
    }
}
