package com.just.agentweb;

import android.os.Handler;
import android.os.Looper;
import android.webkit.WebView;
import java.util.Map;

public class UrlLoaderImpl implements IUrlLoader {
    public static final String TAG = "UrlLoaderImpl";
    private Handler mHandler = null;
    private HttpHeaders mHttpHeaders;
    private WebView mWebView;

    UrlLoaderImpl(WebView webView, HttpHeaders httpHeaders) {
        this.mWebView = webView;
        this.mHttpHeaders = httpHeaders;
        if (httpHeaders == null) {
            this.mHttpHeaders = HttpHeaders.create();
        }
        this.mHandler = new Handler(Looper.getMainLooper());
    }

    private void safeLoadUrl(final String str) {
        this.mHandler.post(new Runnable() {
            /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass1 */

            public void run() {
                UrlLoaderImpl.this.loadUrl(str);
            }
        });
    }

    private void safeReload() {
        this.mHandler.post(new Runnable() {
            /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass2 */

            public void run() {
                UrlLoaderImpl.this.reload();
            }
        });
    }

    @Override // com.just.agentweb.IUrlLoader
    public HttpHeaders getHttpHeaders() {
        HttpHeaders httpHeaders = this.mHttpHeaders;
        if (httpHeaders != null) {
            return httpHeaders;
        }
        HttpHeaders create = HttpHeaders.create();
        this.mHttpHeaders = create;
        return create;
    }

    @Override // com.just.agentweb.IUrlLoader
    public void loadData(final String str, final String str2, final String str3) {
        if (!AgentWebUtils.isUIThread()) {
            this.mHandler.post(new Runnable() {
                /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass5 */

                public void run() {
                    UrlLoaderImpl.this.loadData(str, str2, str3);
                }
            });
        } else {
            this.mWebView.loadData(str, str2, str3);
        }
    }

    @Override // com.just.agentweb.IUrlLoader
    public void loadDataWithBaseURL(final String str, final String str2, final String str3, final String str4, final String str5) {
        if (!AgentWebUtils.isUIThread()) {
            this.mHandler.post(new Runnable() {
                /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass7 */

                public void run() {
                    UrlLoaderImpl.this.loadDataWithBaseURL(str, str2, str3, str4, str5);
                }
            });
        } else {
            this.mWebView.loadDataWithBaseURL(str, str2, str3, str4, str5);
        }
    }

    @Override // com.just.agentweb.IUrlLoader
    public void loadUrl(String str) {
        loadUrl(str, this.mHttpHeaders.getHeaders(str));
    }

    @Override // com.just.agentweb.IUrlLoader
    public void loadUrl(final String str, final Map<String, String> map) {
        if (!AgentWebUtils.isUIThread()) {
            AgentWebUtils.runInUiThread(new Runnable() {
                /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass3 */

                public void run() {
                    UrlLoaderImpl.this.loadUrl(str, map);
                }
            });
            return;
        }
        String str2 = TAG;
        LogUtils.i(str2, "loadUrl:" + str + " headers:" + map);
        if (map == null || map.isEmpty()) {
            this.mWebView.loadUrl(str);
        } else {
            this.mWebView.loadUrl(str, map);
        }
    }

    @Override // com.just.agentweb.IUrlLoader
    public void postUrl(final String str, final byte[] bArr) {
        if (!AgentWebUtils.isUIThread()) {
            this.mHandler.post(new Runnable() {
                /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass8 */

                public void run() {
                    UrlLoaderImpl.this.postUrl(str, bArr);
                }
            });
        } else {
            this.mWebView.postUrl(str, bArr);
        }
    }

    @Override // com.just.agentweb.IUrlLoader
    public void reload() {
        if (!AgentWebUtils.isUIThread()) {
            this.mHandler.post(new Runnable() {
                /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass4 */

                public void run() {
                    UrlLoaderImpl.this.reload();
                }
            });
        } else {
            this.mWebView.reload();
        }
    }

    @Override // com.just.agentweb.IUrlLoader
    public void stopLoading() {
        if (!AgentWebUtils.isUIThread()) {
            this.mHandler.post(new Runnable() {
                /* class com.just.agentweb.UrlLoaderImpl.AnonymousClass6 */

                public void run() {
                    UrlLoaderImpl.this.stopLoading();
                }
            });
        } else {
            this.mWebView.stopLoading();
        }
    }
}
