package kotlin.time;

import java.util.Collection;
import java.util.Iterator;
import kotlin.collections.IntIterator;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.math.MathKt;
import kotlin.ranges.CharRange;
import kotlin.ranges.IntRange;
import kotlin.ranges.LongRange;
import kotlin.ranges.RangesKt;
import kotlin.text.StringsKt;

public final class DurationKt {
    public static final long MAX_MILLIS;
    public static final long MAX_NANOS;
    private static final long MAX_NANOS_IN_MILLIS;
    public static final int NANOS_IN_MILLIS;

    public static /* synthetic */ void getDays$annotations(double d) {
    }

    public static /* synthetic */ void getDays$annotations(int i) {
    }

    public static /* synthetic */ void getDays$annotations(long j) {
    }

    public static /* synthetic */ void getHours$annotations(double d) {
    }

    public static /* synthetic */ void getHours$annotations(int i) {
    }

    public static /* synthetic */ void getHours$annotations(long j) {
    }

    public static /* synthetic */ void getMicroseconds$annotations(double d) {
    }

    public static /* synthetic */ void getMicroseconds$annotations(int i) {
    }

    public static /* synthetic */ void getMicroseconds$annotations(long j) {
    }

    public static /* synthetic */ void getMilliseconds$annotations(double d) {
    }

    public static /* synthetic */ void getMilliseconds$annotations(int i) {
    }

    public static /* synthetic */ void getMilliseconds$annotations(long j) {
    }

    public static /* synthetic */ void getMinutes$annotations(double d) {
    }

    public static /* synthetic */ void getMinutes$annotations(int i) {
    }

    public static /* synthetic */ void getMinutes$annotations(long j) {
    }

    public static /* synthetic */ void getNanoseconds$annotations(double d) {
    }

    public static /* synthetic */ void getNanoseconds$annotations(int i) {
    }

    public static /* synthetic */ void getNanoseconds$annotations(long j) {
    }

    public static /* synthetic */ void getSeconds$annotations(double d) {
    }

    public static /* synthetic */ void getSeconds$annotations(int i) {
    }

    public static /* synthetic */ void getSeconds$annotations(long j) {
    }

    public static final long millisToNanos(long j) {
        return j * ((long) NANOS_IN_MILLIS);
    }

    public static final long toDuration(int i, DurationUnit durationUnit) {
        Intrinsics.checkNotNullParameter(durationUnit, "unit");
        if (durationUnit.compareTo((Enum) DurationUnit.SECONDS) <= 0) {
            return durationOfNanos(DurationUnitKt.convertDurationUnitOverflow((long) i, durationUnit, DurationUnit.NANOSECONDS));
        }
        return toDuration((long) i, durationUnit);
    }

    public static final long toDuration(long j, DurationUnit durationUnit) {
        Intrinsics.checkNotNullParameter(durationUnit, "unit");
        long convertDurationUnitOverflow = DurationUnitKt.convertDurationUnitOverflow(MAX_NANOS, DurationUnit.NANOSECONDS, durationUnit);
        if (new LongRange(-convertDurationUnitOverflow, convertDurationUnitOverflow).contains(j)) {
            return durationOfNanos(DurationUnitKt.convertDurationUnitOverflow(j, durationUnit, DurationUnit.NANOSECONDS));
        }
        return durationOfMillis(RangesKt.coerceIn(DurationUnitKt.convertDurationUnit(j, durationUnit, DurationUnit.MILLISECONDS), -4611686018427387903L, (long) MAX_MILLIS));
    }

    public static final long toDuration(double d, DurationUnit durationUnit) {
        Intrinsics.checkNotNullParameter(durationUnit, "unit");
        double convertDurationUnit = DurationUnitKt.convertDurationUnit(d, durationUnit, DurationUnit.NANOSECONDS);
        if (!Double.isNaN(convertDurationUnit)) {
            long roundToLong = MathKt.roundToLong(convertDurationUnit);
            if (new LongRange(-4611686018426999999L, MAX_NANOS).contains(roundToLong)) {
                return durationOfNanos(roundToLong);
            }
            return durationOfMillisNormalized(MathKt.roundToLong(DurationUnitKt.convertDurationUnit(d, durationUnit, DurationUnit.MILLISECONDS)));
        }
        throw new IllegalArgumentException("Duration value cannot be NaN.".toString());
    }

    public static final long getNanoseconds(int i) {
        return toDuration(i, DurationUnit.NANOSECONDS);
    }

    public static final long getNanoseconds(long j) {
        return toDuration(j, DurationUnit.NANOSECONDS);
    }

    public static final long getNanoseconds(double d) {
        return toDuration(d, DurationUnit.NANOSECONDS);
    }

    public static final long getMicroseconds(int i) {
        return toDuration(i, DurationUnit.MICROSECONDS);
    }

    public static final long getMicroseconds(long j) {
        return toDuration(j, DurationUnit.MICROSECONDS);
    }

    public static final long getMicroseconds(double d) {
        return toDuration(d, DurationUnit.MICROSECONDS);
    }

    public static final long getMilliseconds(int i) {
        return toDuration(i, DurationUnit.MILLISECONDS);
    }

    public static final long getMilliseconds(long j) {
        return toDuration(j, DurationUnit.MILLISECONDS);
    }

    public static final long getMilliseconds(double d) {
        return toDuration(d, DurationUnit.MILLISECONDS);
    }

    public static final long getSeconds(int i) {
        return toDuration(i, DurationUnit.SECONDS);
    }

    public static final long getSeconds(long j) {
        return toDuration(j, DurationUnit.SECONDS);
    }

    public static final long getSeconds(double d) {
        return toDuration(d, DurationUnit.SECONDS);
    }

    public static final long getMinutes(int i) {
        return toDuration(i, DurationUnit.MINUTES);
    }

    public static final long getMinutes(long j) {
        return toDuration(j, DurationUnit.MINUTES);
    }

    public static final long getMinutes(double d) {
        return toDuration(d, DurationUnit.MINUTES);
    }

    public static final long getHours(int i) {
        return toDuration(i, DurationUnit.HOURS);
    }

    public static final long getHours(long j) {
        return toDuration(j, DurationUnit.HOURS);
    }

    public static final long getHours(double d) {
        return toDuration(d, DurationUnit.HOURS);
    }

    public static final long getDays(int i) {
        return toDuration(i, DurationUnit.DAYS);
    }

    public static final long getDays(long j) {
        return toDuration(j, DurationUnit.DAYS);
    }

    public static final long getDays(double d) {
        return toDuration(d, DurationUnit.DAYS);
    }

    /* renamed from: times-mvk6XK0 */
    private static final long m1480timesmvk6XK0(int i, long j) {
        return Duration.m1392timesUwyO8pc(j, i);
    }

    /* renamed from: times-kIfJnKk */
    private static final long m1479timeskIfJnKk(double d, long j) {
        return Duration.m1391timesUwyO8pc(j, d);
    }

    /* JADX WARNING: Removed duplicated region for block: B:161:0x00af A[EDGE_INSN: B:161:0x00af->B:45:0x00af ?: BREAK  , SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x009f A[LOOP:1: B:33:0x006d->B:43:0x009f, LOOP_END] */
    public static final long parseDuration(String str, boolean z) {
        boolean z2;
        int i;
        int i2;
        boolean z3;
        boolean z4;
        int length = str.length();
        if (length != 0) {
            long r8 = Duration.Companion.m1456getZEROUwyO8pc();
            char charAt = str.charAt(0);
            int i3 = (charAt == '+' || charAt == '-') ? 1 : 0;
            boolean z5 = i3 > 0;
            boolean z6 = z5 && StringsKt.startsWith$default(str, '-', false, 2, null);
            if (length > i3) {
                char c = '0';
                if (str.charAt(i3) == 'P') {
                    int i4 = i3 + 1;
                    if (i4 != length) {
                        boolean z7 = false;
                        DurationUnit durationUnit = null;
                        while (i4 < length) {
                            if (str.charAt(i4) != 'T') {
                                int i5 = i4;
                                while (true) {
                                    if (i5 >= str.length()) {
                                        i2 = length;
                                        z3 = z6;
                                        break;
                                    }
                                    char charAt2 = str.charAt(i5);
                                    z3 = z6;
                                    if (!new CharRange(c, '9').contains(charAt2)) {
                                        i2 = length;
                                        if (!StringsKt.contains$default((CharSequence) "+-.", charAt2, false, 2, (Object) null)) {
                                            z4 = false;
                                            if (z4) {
                                                break;
                                            }
                                            i5++;
                                            length = i2;
                                            z6 = z3;
                                            c = '0';
                                        }
                                    } else {
                                        i2 = length;
                                    }
                                    z4 = true;
                                    if (z4) {
                                    }
                                }
                                Intrinsics.checkNotNull(str, "null cannot be cast to non-null type java.lang.String");
                                String substring = str.substring(i4, i5);
                                Intrinsics.checkNotNullExpressionValue(substring, "this as java.lang.String…ing(startIndex, endIndex)");
                                String str2 = substring;
                                if (!(str2.length() == 0)) {
                                    int length2 = i4 + substring.length();
                                    String str3 = str;
                                    if (length2 < 0 || length2 > StringsKt.getLastIndex(str3)) {
                                        throw new IllegalArgumentException("Missing unit for value " + substring);
                                    }
                                    char charAt3 = str3.charAt(length2);
                                    i4 = length2 + 1;
                                    DurationUnit durationUnitByIsoChar = DurationUnitKt.durationUnitByIsoChar(charAt3, z7);
                                    if (durationUnit == null || durationUnit.compareTo((Enum) durationUnitByIsoChar) > 0) {
                                        int indexOf$default = StringsKt.indexOf$default((CharSequence) str2, '.', 0, false, 6, (Object) null);
                                        if (durationUnitByIsoChar != DurationUnit.SECONDS || indexOf$default <= 0) {
                                            r8 = Duration.m1390plusLRDsOJo(r8, toDuration(parseOverLongIsoComponent(substring), durationUnitByIsoChar));
                                        } else {
                                            Intrinsics.checkNotNull(substring, "null cannot be cast to non-null type java.lang.String");
                                            String substring2 = substring.substring(0, indexOf$default);
                                            Intrinsics.checkNotNullExpressionValue(substring2, "this as java.lang.String…ing(startIndex, endIndex)");
                                            long r82 = Duration.m1390plusLRDsOJo(r8, toDuration(parseOverLongIsoComponent(substring2), durationUnitByIsoChar));
                                            Intrinsics.checkNotNull(substring, "null cannot be cast to non-null type java.lang.String");
                                            String substring3 = substring.substring(indexOf$default);
                                            Intrinsics.checkNotNullExpressionValue(substring3, "this as java.lang.String).substring(startIndex)");
                                            r8 = Duration.m1390plusLRDsOJo(r82, toDuration(Double.parseDouble(substring3), durationUnitByIsoChar));
                                        }
                                        durationUnit = durationUnitByIsoChar;
                                        length = i2;
                                        z6 = z3;
                                        c = '0';
                                    } else {
                                        throw new IllegalArgumentException("Unexpected order of duration components");
                                    }
                                } else {
                                    throw new IllegalArgumentException();
                                }
                            } else if (z7 || (i4 = i4 + 1) == length) {
                                throw new IllegalArgumentException();
                            } else {
                                z7 = true;
                            }
                        }
                        z2 = z6;
                    } else {
                        throw new IllegalArgumentException();
                    }
                } else {
                    z2 = z6;
                    if (!z) {
                        String str4 = "this as java.lang.String).substring(startIndex)";
                        if (StringsKt.regionMatches(str, i3, "Infinity", 0, Math.max(length - i3, 8), true)) {
                            r8 = Duration.Companion.m1454getINFINITEUwyO8pc();
                        } else {
                            boolean z8 = !z5;
                            if (z5 && str.charAt(i3) == '(' && StringsKt.last(str) == ')') {
                                i3++;
                                int i6 = length - 1;
                                if (i3 != i6) {
                                    i = i6;
                                    z8 = true;
                                } else {
                                    throw new IllegalArgumentException("No components");
                                }
                            } else {
                                i = length;
                            }
                            boolean z9 = false;
                            DurationUnit durationUnit2 = null;
                            while (i3 < i) {
                                if (z9 && z8) {
                                    while (i3 < str.length()) {
                                        if (!(str.charAt(i3) == ' ')) {
                                            break;
                                        }
                                        i3++;
                                    }
                                }
                                int i7 = i3;
                                while (true) {
                                    if (i7 >= str.length()) {
                                        break;
                                    }
                                    char charAt4 = str.charAt(i7);
                                    if (!(new CharRange('0', '9').contains(charAt4) || charAt4 == '.')) {
                                        break;
                                    }
                                    i7++;
                                }
                                Intrinsics.checkNotNull(str, "null cannot be cast to non-null type java.lang.String");
                                String substring4 = str.substring(i3, i7);
                                Intrinsics.checkNotNullExpressionValue(substring4, "this as java.lang.String…ing(startIndex, endIndex)");
                                String str5 = substring4;
                                if (!(str5.length() == 0)) {
                                    int length3 = i3 + substring4.length();
                                    int i8 = length3;
                                    while (i8 < str.length()) {
                                        if (!new CharRange('a', 'z').contains(str.charAt(i8))) {
                                            break;
                                        }
                                        i8++;
                                    }
                                    Intrinsics.checkNotNull(str, "null cannot be cast to non-null type java.lang.String");
                                    String substring5 = str.substring(length3, i8);
                                    Intrinsics.checkNotNullExpressionValue(substring5, "this as java.lang.String…ing(startIndex, endIndex)");
                                    i3 = length3 + substring5.length();
                                    DurationUnit durationUnitByShortName = DurationUnitKt.durationUnitByShortName(substring5);
                                    if (durationUnit2 == null || durationUnit2.compareTo((Enum) durationUnitByShortName) > 0) {
                                        int indexOf$default2 = StringsKt.indexOf$default((CharSequence) str5, '.', 0, false, 6, (Object) null);
                                        if (indexOf$default2 > 0) {
                                            Intrinsics.checkNotNull(substring4, "null cannot be cast to non-null type java.lang.String");
                                            String substring6 = substring4.substring(0, indexOf$default2);
                                            Intrinsics.checkNotNullExpressionValue(substring6, "this as java.lang.String…ing(startIndex, endIndex)");
                                            long r83 = Duration.m1390plusLRDsOJo(r8, toDuration(Long.parseLong(substring6), durationUnitByShortName));
                                            Intrinsics.checkNotNull(substring4, "null cannot be cast to non-null type java.lang.String");
                                            String substring7 = substring4.substring(indexOf$default2);
                                            Intrinsics.checkNotNullExpressionValue(substring7, str4);
                                            r8 = Duration.m1390plusLRDsOJo(r83, toDuration(Double.parseDouble(substring7), durationUnitByShortName));
                                            if (i3 >= i) {
                                                str4 = str4;
                                            } else {
                                                throw new IllegalArgumentException("Fractional component must be last");
                                            }
                                        } else {
                                            r8 = Duration.m1390plusLRDsOJo(r8, toDuration(Long.parseLong(substring4), durationUnitByShortName));
                                        }
                                        durationUnit2 = durationUnitByShortName;
                                        z9 = true;
                                    } else {
                                        throw new IllegalArgumentException("Unexpected order of duration components");
                                    }
                                } else {
                                    throw new IllegalArgumentException();
                                }
                            }
                        }
                    } else {
                        throw new IllegalArgumentException();
                    }
                }
                if (z2) {
                    return Duration.m1406unaryMinusUwyO8pc(r8);
                }
                return r8;
            }
            throw new IllegalArgumentException("No components");
        }
        throw new IllegalArgumentException("The string is empty");
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0064  */
    private static final long parseOverLongIsoComponent(String str) {
        boolean z;
        int length = str.length();
        int i = (length <= 0 || !StringsKt.contains$default("+-", str.charAt(0), false, 2, null)) ? 0 : 1;
        if (length - i > 16) {
            IntRange intRange = new IntRange(i, StringsKt.getLastIndex(str));
            if (!(intRange instanceof Collection) || !((Collection) intRange).isEmpty()) {
                Iterator it = intRange.iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    if (!new CharRange('0', '9').contains(str.charAt(((IntIterator) it).nextInt()))) {
                        z = false;
                        break;
                    }
                }
                if (z) {
                    return str.charAt(0) == '-' ? Long.MIN_VALUE : Long.MAX_VALUE;
                }
            }
            z = true;
            if (z) {
            }
        }
        if (StringsKt.startsWith$default(str, "+", false, 2, (Object) null)) {
            str = StringsKt.drop(str, 1);
        }
        return Long.parseLong(str);
    }

    private static final int skipWhile(String str, int i, Function1<? super Character, Boolean> function1) {
        while (i < str.length() && function1.invoke(Character.valueOf(str.charAt(i))).booleanValue()) {
            i++;
        }
        return i;
    }

    public static final long nanosToMillis(long j) {
        return j / ((long) NANOS_IN_MILLIS);
    }

    public static final long durationOfNanos(long j) {
        return Duration.m1354constructorimpl(j << 1);
    }

    public static final long durationOfMillis(long j) {
        return Duration.m1354constructorimpl((j << 1) + 1);
    }

    public static final long durationOf(long j, int i) {
        return Duration.m1354constructorimpl((j << 1) + ((long) i));
    }

    public static final long durationOfNanosNormalized(long j) {
        if (new LongRange(-4611686018426999999L, MAX_NANOS).contains(j)) {
            return durationOfNanos(j);
        }
        return durationOfMillis(nanosToMillis(j));
    }

    public static final long durationOfMillisNormalized(long j) {
        if (new LongRange(-4611686018426L, MAX_NANOS_IN_MILLIS).contains(j)) {
            return durationOfNanos(millisToNanos(j));
        }
        return durationOfMillis(RangesKt.coerceIn(j, -4611686018427387903L, (long) MAX_MILLIS));
    }

    private static final String substringWhile(String str, int i, Function1<? super Character, Boolean> function1) {
        int i2 = i;
        while (i2 < str.length() && function1.invoke(Character.valueOf(str.charAt(i2))).booleanValue()) {
            i2++;
        }
        Intrinsics.checkNotNull(str, "null cannot be cast to non-null type java.lang.String");
        String substring = str.substring(i, i2);
        Intrinsics.checkNotNullExpressionValue(substring, "this as java.lang.String…ing(startIndex, endIndex)");
        return substring;
    }
}
