package com.download.library;

import android.content.Context;
import android.content.IntentFilter;
import android.text.TextUtils;
import java.io.File;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

public final class DownloadImpl {
    private static final String TAG = "Download-DownloadImpl";
    private static volatile Context mContext;
    private static volatile DownloadImpl sInstance;
    private final ConcurrentHashMap<String, DownloadTask> mTasks = new ConcurrentHashMap<>();

    private DownloadImpl(Context context) {
        if (mContext == null) {
            synchronized (DownloadImpl.class) {
                if (mContext == null) {
                    Context applicationContext = context.getApplicationContext();
                    mContext = applicationContext;
                    String append = Runtime.getInstance().append(context, NotificationCancelReceiver.ACTION);
                    applicationContext.registerReceiver(new NotificationCancelReceiver(), new IntentFilter(append));
                    Runtime instance = Runtime.getInstance();
                    String str = TAG;
                    instance.log(str, "registerReceiver:" + append);
                }
            }
        }
    }

    public static DownloadImpl getInstance(Context context) {
        if (sInstance == null) {
            synchronized (DownloadImpl.class) {
                if (sInstance == null) {
                    sInstance = new DownloadImpl(context);
                }
            }
        }
        return sInstance;
    }

    public static ResourceRequest with(Context context) {
        return getInstance(context).with0(context);
    }

    public ResourceRequest with(String str) {
        return ResourceRequest.with(mContext).url(str);
    }

    public ResourceRequest url(String str) {
        return ResourceRequest.with(mContext).url(str);
    }

    private ResourceRequest with0(Context context) {
        return ResourceRequest.with(mContext);
    }

    private void safe(DownloadTask downloadTask) {
        if (downloadTask.getContext() == null) {
            throw new NullPointerException("context can't be null .");
        } else if (TextUtils.isEmpty(downloadTask.getUrl())) {
            throw new NullPointerException("url can't be empty .");
        }
    }

    public boolean enqueue(DownloadTask downloadTask) {
        safe(downloadTask);
        return DownloadSubmitterImpl.getInstance().submit(downloadTask);
    }

    public File call(DownloadTask downloadTask) {
        safe(downloadTask);
        try {
            return DownloadSubmitterImpl.getInstance().submit0(downloadTask);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public File callEx(DownloadTask downloadTask) throws Exception {
        safe(downloadTask);
        return DownloadSubmitterImpl.getInstance().submit0(downloadTask);
    }

    /* JADX INFO: finally extract failed */
    public synchronized DownloadTask cancel(String str) {
        DownloadTask cancelTask;
        try {
            cancelTask = ExecuteTasksMap.getInstance().cancelTask(str);
            DownloadTask downloadTask = this.mTasks.get(str);
            if (downloadTask != null && downloadTask.getStatus() == 1004) {
                downloadTask.cancel();
                DownloadNotifier.cancel(downloadTask);
                cancelTask = downloadTask;
            }
            remove(str);
        } catch (Throwable th) {
            DownloadTask downloadTask2 = this.mTasks.get(str);
            if (downloadTask2 != null && downloadTask2.getStatus() == 1004) {
                downloadTask2.cancel();
                DownloadNotifier.cancel(downloadTask2);
            }
            remove(str);
            throw th;
        }
        return cancelTask;
    }

    /*  JADX ERROR: StackOverflowError in pass: MarkFinallyVisitor
        java.lang.StackOverflowError
        	at jadx.core.dex.nodes.InsnNode.isSame(InsnNode.java:303)
        	at jadx.core.dex.instructions.IfNode.isSame(IfNode.java:122)
        	at jadx.core.dex.visitors.MarkFinallyVisitor.sameInsns(MarkFinallyVisitor.java:451)
        	at jadx.core.dex.visitors.MarkFinallyVisitor.compareBlocks(MarkFinallyVisitor.java:436)
        	at jadx.core.dex.visitors.MarkFinallyVisitor.checkBlocksTree(MarkFinallyVisitor.java:408)
        	at jadx.core.dex.visitors.MarkFinallyVisitor.checkBlocksTree(MarkFinallyVisitor.java:411)
        */
    public synchronized java.util.List<com.download.library.DownloadTask> cancelAll() {
        /*
        // Method dump skipped, instructions count: 138
        */
        throw new UnsupportedOperationException("Method not decompiled: com.download.library.DownloadImpl.cancelAll():java.util.List");
    }

    public synchronized DownloadTask pause(String str) {
        DownloadTask pauseTask;
        pauseTask = ExecuteTasksMap.getInstance().pauseTask(str);
        if (pauseTask != null) {
            this.mTasks.put(pauseTask.getUrl(), pauseTask);
        }
        return pauseTask;
    }

    public synchronized void resumeAll() {
        ConcurrentHashMap<String, DownloadTask> concurrentHashMap = this.mTasks;
        if (concurrentHashMap.size() > 0) {
            Set<Map.Entry<String, DownloadTask>> entrySet = concurrentHashMap.entrySet();
            if (entrySet.size() > 0) {
                for (Map.Entry<String, DownloadTask> entry : entrySet) {
                    DownloadTask value = entry.getValue();
                    if (value == null || value.getContext() == null || TextUtils.isEmpty(value.getUrl())) {
                        Runtime.getInstance().logError(TAG, "downloadTask death .");
                    } else {
                        Runtime instance = Runtime.getInstance();
                        String str = TAG;
                        instance.logError(str, "downloadTask:" + value.getUrl());
                        enqueue(value);
                    }
                }
            }
            cleanTasksCache();
        }
    }

    public synchronized boolean resume(String str) {
        DownloadTask remove = this.mTasks.remove(str);
        if (!(remove == null || remove.getContext() == null)) {
            if (!TextUtils.isEmpty(remove.getUrl())) {
                enqueue(remove);
                return true;
            }
        }
        Runtime.getInstance().logError(TAG, "downloadTask death .");
        return false;
    }

    private synchronized void cleanTasksCache() {
        this.mTasks.clear();
    }

    private synchronized void remove(String str) {
        this.mTasks.remove(str);
    }

    public boolean exist(String str) {
        return ExecuteTasksMap.getInstance().exist(str) || this.mTasks.contains(str);
    }

    public boolean isPaused(String str) {
        DownloadTask downloadTask = this.mTasks.get(str);
        return downloadTask != null && downloadTask.getStatus() == 1004;
    }

    public int pausedTasksTotals() {
        return this.mTasks.size();
    }

    public boolean isRunning(String str) {
        return ExecuteTasksMap.getInstance().exist(str);
    }
}
